from typing import Callable

import reflex as rx


class InputsV4State(rx.State):
    is_open: bool = False
    string: str
    tip: str = "Password must include at least 6 characters"

    def on_entry_focus(self, event=None):
        self.is_open = not self.is_open

    def on_entry_blur(self, event=None):
        self.is_open = False

    def entry_value_update(self, value: str):
        self.string = value

        self.tip = (
            "All good!"
            if len(self.string) >= 6
            else "Password must include at least 6 characters"
        )


title: Callable[[str], rx.Component] = lambda name: rx.text(
    name, size="1", weight="bold", color=rx.color("slate", 11)
)


tip: Callable[[], rx.Component] = lambda: rx.tooltip(
    rx.icon(
        tag="info",
        position="absolute",
        bottom="0",
        left="0",
        opacity="0",
    ),
    content=InputsV4State.tip,
    side="bottom",
    align="start",
    padding="0.5em",
    open=InputsV4State.is_open,
)

entry: Callable[[str], rx.Component] = lambda placeholder: rx.input(
    tip(),
    placeholder=placeholder,
    outline="none",
    variant="soft",
    width="100%",
    overflow="hidden",
    position="relative",
    display="flex",
    align_items="center",
    height="40px",
    background=rx.color("gray", 4),
    type="password",
    on_focus=InputsV4State.on_entry_focus,
    on_blur=InputsV4State.on_entry_blur,
    on_change=InputsV4State.entry_value_update,
)


def inputs_v4():
    return rx.vstack(
        title("Show tooltip on focus"),
        entry("Your password"),
        width="100%",
        max_width="25em",
        spacing="1",
    )



import reflex as rx
from typing import List, Dict

from reflex.constants.colors import Color

from .style import SideMenuStyle
from ..wrapper.wrapper import menu_wrapper
from ...states.routing import SiteRoutingState


def create_sidebar_menu_items(routes: List[Dict[str, str | Color]]):

    def item(data):
        return rx.hstack(
            rx.link(
                rx.text(
                    data["name"],
                    size="1",
                    weight="medium",
                    color=rx.color("slate", 12),
                ),
                href=data["path"],
                text_decoration="none",
                on_click=lambda: SiteRoutingState.toggle_page_change(data),
            ),
            rx.cond(
                data["is_beta"],
                rx.badge("In Progress", color_scheme="orange"),
                rx.cond(
                    data["is_new"],
                    rx.badge("New", color_scheme="grass"),
                    rx.spacer(),
                ),
            ),
            border_left=data["border_left"],
            background=data["background"],
            width="100%",
            align="center",
            height="26px",
            padding_left="20px",
            border_radius="0px 6px 6px 0px",
        )

    return rx.vstack(
        rx.foreach(routes, item),
        spacing="0",
        width="100%",
    )


def top_scroll_fade_out():
    return rx.box(
        top="0",
        left="0",
        position="fixed",
        width="100%",
        height="10%",
        z_index="20",
        background=rx.color("gray", 2),
        mask="linear-gradient(to bottom, hsl(0, 0%, 0%, 1) 55%, hsl(0, 0%, 0%, 0) 100%)",
    )


def sidemenu() -> rx.vstack:
    return rx.vstack(
        top_scroll_fade_out(),
        rx.vstack(
            menu_wrapper(
                "Getting Started",
                [create_sidebar_menu_items(SiteRoutingState.GettingStartedRoutes)],
            ),
            menu_wrapper(
                "Interactive Applications",
                [create_sidebar_menu_items(SiteRoutingState.InteractiveRoutes)],
            ),
            menu_wrapper(
                "Blueprint Templates",
                [create_sidebar_menu_items(SiteRoutingState.BlueprintRoutes)],
            ),
            menu_wrapper(
                "Chart Components",
                [create_sidebar_menu_items(SiteRoutingState.ChartRoutes)],
            ),
            menu_wrapper(
                "Pantry Components",
                [create_sidebar_menu_items(SiteRoutingState.PantryRoutes)],
            ),
            **SideMenuStyle.content,
        ),
        **SideMenuStyle.base,
    )



import reflex as rx


class Content(rx.State):
    links: list[dict[str, str]] = [
        {"label": "Usage", "link": "#usage", "color": "gray"},
        {"label": "Position and placement", "link": "#position", "color": "gray"},
        {"label": "With other overlays", "link": "#overlays", "color": "gray"},
        {"label": "Manage focus", "link": "#focus", "color": "gray"},
        {"label": "Examples", "link": "#1", "color": "gray"},
        {"label": "Show on focus", "link": "#2", "color": "gray"},
        {"label": "Show on hover", "link": "#3", "color": "gray"},
        {"label": "With form", "link": "#4", "color": "gray"},
    ]

    index: int = 0
    position_y: str = "10px"

    async def toggle_table_content(self, index: int, item: dict[str, str]):
        self.links = [
            (
                {**data, "color": rx.color("slate", 11)}
                if data["label"] != item["label"]
                else {**data, "color": rx.color("slate", 12)}
            )
            for data in self.links
        ]
        self.position_y = f"{10 + (index * 30)}px"


def items(index: int, data: dict[str, str]):
    return rx.hstack(
        rx.link(
            rx.text(
                data["label"],
                font_size="12px",
                color=data["color"],
                weight="medium",
                on_click=Content.toggle_table_content(index, data),
            ),
            href=data["link"],
            text_decoration="none",
        ),
        border_left=f"1px solid {rx.color('gray', 5)}",
        width="200px",
        height="30px",
        align="center",
        justify="start",
        padding_left="15px",
        border_radius="0px 5px 5px 0px",
    )


def item_header():
    return rx.hstack(
        rx.text("Menu Items", font_size="11px", color_scheme="gray", weight="medium"),
        rx.icon(tag="puzzle", size=12),
        width="100%",
        justify="between",
        align="center",
        border_left=f"1px solid {rx.color('gray', 5)}",
        border_radius="0px 5px 5px 0px",
        padding_left="15px",
        padding_right="15px",
        height="30px",
        bg=rx.color("gray", 3),
    )


def menus_v1():
    return rx.vstack(
        item_header(),
        rx.vstack(
            rx.box(
                width="10px",
                height="10px",
                border_radius="10px",
                bg=rx.color("blue"),
                position="absolute",
                left="-4.5px",
                top=Content.position_y,
                transition="all 200ms ease-out",
            ),
            rx.foreach(
                Content.links,
                lambda data, index: items(index, data),
            ),
            spacing="0",
            position="relative",
        ),
        spacing="0",
    )



from dataclasses import dataclass, field

import reflex as rx


@dataclass
class AppProfileWrapperStyle:
    blip: dict[str, str] = field(
        default_factory=lambda: {
            "width": "24px",
            "height": "24px",
            "border_radius": "24px",
            "background": rx.color("gray", 3),
            "border": f"1.25px solid {rx.color('gray', 6)}",
            "position": "absolute",
            "left": "-12px",
            "align_items": "center",
            "justify_content": "center",
            "display": "flex",
        }
    )

    wrapper: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "align": "start",
            "justify": "start",
            "padding_left": "5px",
            "border_radius": "0px 5px 5px 0px",
        }
    )


AppProfileWrapperStyle: AppProfileWrapperStyle = AppProfileWrapperStyle()



import reflex as rx


def blip():
    return rx.box(
        width="10px",
        height="10px",
        border_radius="10px",
        background=rx.color("blue"),
        position="absolute",
        left="-5px",
    )


def wrapper(
    title: str, instructions: str, components: list[rx.Component] = [], **kwargs
):
    return rx.hstack(
        rx.vstack(
            rx.vstack(
                rx.hstack(
                    blip(),
                    rx.text(
                        title, size="1", weight="medium", color=rx.color("slate", 11)
                    ),
                    align="center",
                ),
                rx.text(
                    instructions, size="3", weight="bold", color=rx.color("slate", 12)
                ),
                spacing="1",
            ),
            *components,
        ),
        width="100%",
        align="start",
        justify="start",
        padding_left="15px",
        border_radius="0px 5px 5px 0px",
        **kwargs,
    )


def timeline_v1():
    return rx.vstack(
        rx.vstack(
            rx.box(
                wrapper(
                    "2023 - Present",
                    "Web Designer & Web Developer",
                    [
                        rx.text(
                            "The company has high expectations, and by using OKRs (Objectives and Key Results), there is a mutual understanding of expectations and performance. This framework not only aligns individual and team goals with the company's strategic vision but also fosters accountability and transparency throughout the organization.Regular check-ins and progress updates ensure that everyone stays on track, allowing for timely adjustments when necessary. The collaborative nature of setting OKRs encourages open communication, enabling team members to share insights and challenges.",
                            size="1",
                        ),
                    ],
                ),
                position="relative",
            ),
            rx.box(
                wrapper(
                    "2021 - 2023",
                    "Senior Software Engineer at Mailchimp",
                    [
                        rx.text(
                            "This is an excellent company and they reward their employees. It's becoming a big company but it's still private, so the culture is as good as it gets at 1,000+ employees if you ask me. Managers are still adapting to the growth I think, but everyone has to. Great place to work. ",
                            size="1",
                        ),
                    ],
                ),
                position="relative",
            ),
            rx.box(
                wrapper(
                    "2021 - 2021",
                    "Junior Software Engineer at Slack",
                    [
                        rx.text(
                            "Work in Slack is one of the beautiful experience I can do in my entire life. There are a lot of interesting thing to learn and manager respect your time and your personality.",
                            size="1",
                        ),
                    ],
                ),
                position="relative",
            ),
            width="100%",
            border_left=f"1px solid {rx.color('gray', 5)}",
            spacing="7",
        ),
        width="100%",
        max_width="40em",
        align="center",
        justify="start",
        padding="24px 12px",
        overflow="auto",
    )



from reflex.components.radix.themes.layout.stack import VStack
from dataclasses import dataclass, field
import reflex as rx
import asyncio


@dataclass
class Style:
    base: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "height": "20em",
            "align": "center",
            "justify": "center",
            "position": "relative",
        }
    )

    button: dict[str, str] = field(
        default_factory=lambda: {
            "top": "-24px",
            "right": "-12px",
            "cursor": "pointer",
            "position": "absolute",
            "border_radius": "0px 0px 0px 8px",
        }
    )

    fade: dict[str, str] = field(
        default_factory=lambda: {
            "position": "relative",
            f"@keyframes opacity": {
                "0%": {"opacity": "0"},
                "100%": {"opacity": "1"},
            },
            "animation": "opacity 1s",
        }
    )


Style: Style = Style()


class Animation(rx.State):
    animate: dict[str, str] = {}
    is_disabled: bool = False

    async def run_animation(self):
        if self.is_disabled:
            return

        self.is_disabled = True
        self.animate = Style.fade
        yield

        await asyncio.sleep(1.1)
        self.is_disabled = False
        self.animate = {}


def animation_v1() -> VStack:
    return rx.vstack(
        rx.heading("buridan/ui", size="5", font_weight="900", style=Animation.animate),
        rx.button(
            "Run",
            loading=Animation.is_disabled,
            on_click=Animation.run_animation,
            **Style.button,
        ),
        **Style.base,
    )



import reflex as rx
from dataclasses import dataclass, field


@dataclass
class LoginStyle:
    base: dict[str, str] = field(default_factory=lambda: {"width": "100%"})

    LoginButton: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "cursor": "pointer",
            "variant": "surface",
            "color_scheme": "gray",
        }
    )


LoginStyle: LoginStyle = LoginStyle()


def login_button(name: str, *args) -> rx.button:
    return rx.button(*args, name, **LoginStyle.LoginButton)


def hero_login_01():

    return rx.badge(
        rx.vstack(
            rx.vstack(
                rx.heading("Create an account", size="3", weight="bold"),
                rx.text(
                    "Enter your email below.",
                    size="2",
                    weight="medium",
                    color_scheme="gray",
                    align="center",
                ),
                width="100%",
                spacing="1",
                align="center",
            ),
            rx.input(width="100%", placeholder="email@me.com"),
            login_button("Sign In with Email"),
            rx.hstack(
                rx.divider(width="30%"),
                rx.text("OR CONTINUE WITH", font_size="10px", color_scheme="gray"),
                rx.divider(width="30%"),
                width="100%",
                align="center",
                justify="center",
                padding="5px 0px",
            ),
            login_button("Sign In with Email", rx.icon(tag="github", size=14)),
            **LoginStyle.base,
        ),
        variant="surface",
        color_scheme="gray",
        padding="2em",
        border_radius="15px",
        max_width="25em",
        **{
            "position": "relative",
            f"@keyframes intro": {
                "0%": {
                    "filter": "blur(10px)",
                    "transform": "scale(1.5)",
                    "opacity": "0",
                },
                "100%": {
                    "filter": "blur(0px)",
                    "transform": "scale(1)",
                    "opacity": "1",
                },
            },
            "animation": "intro 300ms ease",
            # "transition": "filter 300ms ease 2s, transform 300ms ease 2s, opacity 300ms ease 2s",
        },
    )


def logins_v2():

    return rx.badge(
        rx.vstack(
            rx.vstack(
                rx.heading("Create an account", size="5", weight="bold"),
                rx.text(
                    "Enter your email below to create your account",
                    font_size="12px",
                    weight="medium",
                    color_scheme="gray",
                ),
                width="100%",
                spacing="1",
                align="center",
            ),
            rx.hstack(
                login_button("GitHub", rx.icon(tag="github", size=15)),
                width="100%",
            ),
            rx.hstack(
                rx.divider(width="30%"),
                rx.text("OR CONTINUE WITH", font_size="10px", color_scheme="gray"),
                rx.divider(width="30%"),
                width="100%",
                align="center",
                justify="center",
                padding="5px 0px",
            ),
            rx.input(width="100%", placeholder="something@example.com"),
            rx.input(width="100%", placeholder="password", type="password"),
            rx.button(
                "Create Account",
                width="100%",
                cursor="pointer",
                variant="surface",
                color_scheme="gray",
            ),
            **LoginStyle.base,
        ),
        width="100%",
        max_width="25em",
        variant="surface",
        color_scheme="gray",
        padding="2em",
        border_radius="15px",
        **{
            "position": "relative",
            f"@keyframes intro": {
                "0%": {
                    "filter": "blur(10px)",
                    "transform": "scale(1.5)",
                    "opacity": "0",
                },
                "100%": {
                    "filter": "blur(0px)",
                    "transform": "scale(1)",
                    "opacity": "1",
                },
            },
            "animation": "intro 300ms ease",
            # "transition": "filter 300ms ease, transform 300ms ease, opacity 300ms ease",
        },
    )



import reflex as rx
from typing import Callable
from .style import FeaturesStyle

features = {
    0: {
        "tag": "sun-moon",
        "title": "Light & Dark Mode",
        "description": "Easily switch between themes.",
    },
    1: {
        "tag": "copyright",
        "title": "Open Source License",
        "description": "Free, flexible, and open usage.",
    },
    2: {
        "tag": "component",
        "title": "Pre-designed Components",
        "description": "Simple copy-and-paste components.",
    },
    3: {
        "tag": "table-columns-split",
        "title": "Interactive Elements",
        "description": "Engage users with interactive features.",
    },
    4: {
        "tag": "code",
        "title": "Pure Python",
        "description": "Single stack, single language solution.",
    },
    5: {
        "tag": "bot-message-square",
        "title": "A.I. Applications",
        "description": "Seamlessly integrate A.I. functionality.",
    },
    6: {
        "tag": "download",
        "title": "Easy Deployment",
        "description": "One-click installation for quick setup.",
    },
    7: {
        "tag": "frame",
        "title": "Minimalistic Design",
        "description": "Clean, simple, and sleek UI designs.",
    },
}


feature_item_title: Callable[[str, str], rx.Component] = lambda tag, title: rx.hstack(
    rx.badge(
        rx.icon(tag=tag, size=20),
        variant="surface",
        width="21px",
        height="21px",
        padding="5px",
    ),
    rx.text(title, weight="bold", size="2", color=rx.color("slate", 12)),
    align="center",
    spacing="2",
)

feature_item_description: Callable[[str], rx.Component] = lambda description: rx.hstack(
    rx.text(description, weight="medium", size="1", color=rx.color("slate", 11))
)


feature_item: Callable[[str, str, str], rx.Component] = lambda _, __, ___: rx.vstack(
    feature_item_title(_, __),
    feature_item_description(___),
    **FeaturesStyle.base_item,
)

feature: Callable[[], rx.Component] = lambda: rx.hstack(
    *[
        feature_item(item["tag"], item["title"], item["description"])
        for item in features.values()
    ],
    **FeaturesStyle.base,
)



from typing import Callable
from dataclasses import dataclass, field
from reflex.constants.colors import Color

import reflex as rx

color: Callable[[int], Color] = lambda shade: rx.color("slate", shade)
TextShared: dict[str, str] = {"size": "2", "weight": "bold"}


@dataclass
class CardV1Style:
    base: dict[str, str] = field(
        default_factory=lambda: {
            "align": "start",
            "justify": "start",
            "position": "relative",
            "width": "100%",
            "max_width": "320px",
            "height": "200px",
            "border": f"1px solid {rx.color('gray', 6)}",
            "bg": rx.color("gray", 3),
            "border_radius": "12px",
            "padding": "16px",
            "overflow": "hidden",
            "z_index": "30",
            "box_shadow": "0px 6px 12px 0px rgba(0, 0, 0, 0.05)",
        }
    )

    icon: dict[str, str] = field(
        default_factory=lambda: {
            "size": 21,
            "position": "absolute",
            "bottom": "16px",
            "right": "16px",
        }
    )

    stack: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "spacing": "1",
            "align": "start",
            "justify": "start",
            "text_align": "start",
        }
    )

    background: dict[str, str] = field(
        default_factory=lambda: {
            "background_size": "16px 16px",
            "background_image": f"radial-gradient(circle, {rx.color('gray', 12)} 1px, transparent 1px)",
            "mask": f"radial-gradient(100% 100% at 100% 100%, hsl(0, 0%, 0%, 0.81), hsl(0, 0%, 0%, 0))",
            "width": "100%",
            "height": "100%",
            "position": "absolute",
        }
    )

    title: dict[str, str] = field(
        default_factory=lambda: {"color": color(12), **TextShared}
    )

    description: dict[str, str] = field(
        default_factory=lambda: {"color": color(11), **TextShared}
    )


CardV1Style: CardV1Style = CardV1Style()


def card_v1():
    return rx.hstack(
        rx.vstack(
            rx.text("Interactive User Logins", **CardV1Style.title),
            rx.text(
                "Explore our intuitive and secure user login system, designed to streamline the authentication process.",
                **CardV1Style.description,
            ),
            **CardV1Style.stack,
        ),
        rx.box(**CardV1Style.background),
        rx.icon(tag="puzzle", **CardV1Style.icon),
        **CardV1Style.base,
    )



import reflex as rx


def text_wrapper(title: str, description: str):
    return rx.vstack(
        rx.hstack(
            rx.text(
                title,
                size="4",
                weight="bold",
                color=rx.color("slate", 12),
            ),
            align="center",
        ),
        rx.text(description, size="3", color=rx.color("slate", 11), weight="medium"),
        spacing="2",
        line_height="2px",
    )


def introduction():
    return rx.box(
        rx.vstack(
            text_wrapper(
                "Introduction",
                "Welcome to a collection of beautifully designed components that you can seamlessly integrate into your applications. Accessible, customizable, and completely open source.",
            ),
            text_wrapper(
                "What makes this different?",
                "This isn’t just another component library. Rather than installing a package or adding a dependency through pip, you’ll find a curated selection of reusable components that you can easily copy and paste directly into your projects.",
            ),
            text_wrapper(
                "How does it work?",
                "Simply choose the components you need, copy the code, and customize it to suit your unique requirements. The code is yours to modify and enhance as you see fit.",
            ),
            text_wrapper(
                "",
                "Check out the installation section for more details.",
            ),
            text_wrapper(
                "",
                "Think of this as a valuable reference to inspire and guide you in building your own component libraries. Happy coding!",
            ),
            max_width="50em",
            width="100%",
            spacing="6",
        ),
        width="100%",
        display="flex",
        justify_content="center",
        padding="0px 14px",
    )



from dataclasses import dataclass, field

import reflex as rx


@dataclass
class Typography:
    active: dict[str, str] = field(
        default_factory=lambda: {"color": rx.color("slate", 12)}
    )

    passive: dict[str, str] = field(
        default_factory=lambda: {"color": rx.color("slate", 10)}
    )


@dataclass
class Style:
    base: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "min_height": "100vh",
        }
    )

    navigation_parent: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "height": "30px",
            "radius": "none",
            "padding": "0em 5em",
            "top": "0",
            "left": "0",
            "position": "absolute",
        }
    )

    navigation_child: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "justify": "between",
            "align": "center",
        }
    )

    content: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "height": "100%",
            "align": "center",
            "display": "grid",
            "grid_template_columns": [
                f"repeat({i}, minmax(0, 1fr))" for i in [1, 1, 1, 1, 2, 2]
            ],
        }
    )

    profile_base: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "height": "100%",
            "align": "center",
        }
    )

    profile_inner_content: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "height": "100%",
            "position": "relative",
            "padding": "0em 24px",
            "spacing": "8",
            "border_left": f"1px solid {rx.color('gray', 6)}",
        },
    )

    profile_activity_stat_hstack: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "display": "grid",
            "grid_template_columns": [
                f"repeat({i}, minmax(0, 1fr))" for i in [1, 1, 2, 2, 2, 2]
            ],
            "gap": ["12px" if i <= 3 else "32px" for i in range(6)],
        }
    )

    chat_area_base: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "height": "50vh",
            "align": "center",
            "padding": "0em 24px",
        }
    )


Typography: Typography = Typography()

Style: Style = Style()



import reflex as rx
from typing import Callable

from .style import SandboxAuthStyle
from .state import SandboxAuthState, numberList

from .components.borders import createAuthBorders

authTitle: Callable[[str], rx.text] = lambda name: rx.text(
    name, size="5", weight="bold", color=rx.color("slate", 12)
)

authSubtitle: Callable[[str], rx.text] = lambda name: rx.text(
    name, size="2", weight="regular", color=rx.color("slate", 11)
)

authNumberButton: Callable[[str], rx.button] = lambda name: rx.button(
    name,
    width="100%",
    size="2",
    variant="surface",
    cursor="pointer",
    padding="1.5em",
    loading=SandboxAuthState.authGenButton["loading"],
    disabled=SandboxAuthState.authGenButton["disabled"],
    on_click=SandboxAuthState.run_animation_task,
)

authLoginButton: Callable[[str], rx.button] = lambda name: rx.button(
    name,
    width="100%",
    size="2",
    variant="surface",
    cursor="pointer",
    padding="1.5em",
)

authLoginEntry: Callable[[], rx.button] = lambda: rx.input(
    width="100%",
    variant="surface",
    height="3em",
    text_align="center",
    font_size="18px",
)

authInterPageLinking: Callable[[str, str, str, str], rx.text] = (
    lambda start, link, path, end: rx.text(
        start,
        rx.link(f"{link}", href=path),
        end,
        size="1",
        max_width="18em",
        z_index="4",
    )
)

createAuthAccountNumber: Callable[[list[str]], rx.hstack] = (
    lambda numberList: rx.hstack(
        *[
            rx.text(getattr(SandboxAuthState, number), size="5")
            for number in numberList
        ],
        spacing="1",
        align="center",
    )
)
authAccountNumber: Callable[[], rx.hstack] = lambda: rx.hstack(
    createAuthAccountNumber(numberList[:4]),
    createAuthAccountNumber(numberList[4:8]),
    createAuthAccountNumber(numberList[8:12]),
    createAuthAccountNumber(numberList[12:16]),
    spacing="5",
    padding="0.35em",
    align="center",
    border_radius="8px",
    _hover={"bg": rx.color("gray", 3), "cursor": "pointer"},
    on_click=SandboxAuthState.can_copy_account_number,
)


authAlertText: Callable[[], rx.text] = lambda: rx.hstack(
    rx.text(
        "Copy the ",
        rx.text.strong("account number"),
        " above and store it in a safe place. It's the ",
        rx.text.strong("ONLY"),
        " identifier you have to access our services.",
        size="1",
        color_scheme="ruby",
    ),
    background=rx.color("ruby", 3),
    border=f"1.5px solid {rx.color('ruby')}",
    padding="0.5em",
    transition="filter 300ms ease 200ms, transform 300ms ease 200ms, opacity 300ms ease 200ms",
    height=SandboxAuthState.authAlert["height"],
    filter=SandboxAuthState.authAlert["filter"],
    transform=SandboxAuthState.authAlert["transform"],
    opacity=SandboxAuthState.authAlert["opacity"],
)

top = createAuthBorders("top", "left")
bottom = createAuthBorders("bottom", "left")
left = createAuthBorders("left", "bottom")
right = createAuthBorders("right", "bottom")


sandboxAuthCreateAccount: Callable[[], rx.center] = lambda: rx.center(
    rx.box(
        *[top, bottom, left, right],
        rx.vstack(
            authTitle("Create Account"),
            authSubtitle("Click the button below to generate a unique account number."),
            rx.divider(height="0.5em", opacity="0"),
            authNumberButton("Generate Account Number"),
            rx.divider(height="0.5em", opacity="0"),
            authAccountNumber(),
            rx.divider(height="0.5em", opacity="0"),
            authAlertText(),
            rx.divider(height="0.5em", opacity="0"),
            authInterPageLinking(
                "Already have an account number? Click ",
                "here",
                "#",
                " to get started.",
            ),
            **SandboxAuthStyle.content,
        ),
        position="relative",
    ),
    **SandboxAuthStyle.base,
)


sandboxAuthAccountLogin: Callable[[], rx.center] = lambda: rx.center(
    rx.box(
        *[top, bottom, left, right],
        rx.vstack(
            authTitle("Account Login"),
            authSubtitle(
                "Enter your account number below to access your account dashboards."
            ),
            rx.divider(height="0.5em", opacity="0"),
            authLoginEntry(),
            rx.divider(height="0.5em", opacity="0"),
            authLoginButton("Account Login"),
            rx.divider(height="0.5em", opacity="0"),
            authInterPageLinking(
                "Looking for your account number? Click ",
                "here",
                "#",
                " to get one.",
            ),
            **SandboxAuthStyle.content,
        ),
        position="relative",
    ),
    **SandboxAuthStyle.base,
)


sandboxAuth: Callable[[], rx.vstack] = lambda: rx.vstack(
    sandboxAuthCreateAccount(), sandboxAuthAccountLogin(), width="100%", align="center"
)



import reflex as rx

from ..style import tooltip_styles, info
from ...wrappers.state import ComponentWrapperState


def areachart_v5():

    data = [
        {"date": "Apr 01", "desktop": 222, "mobile": 150},
        {"date": "Apr 02", "desktop": 97, "mobile": 180},
        {"date": "Apr 03", "desktop": 167, "mobile": 120},
        {"date": "Apr 04", "desktop": 242, "mobile": 260},
        {"date": "Apr 05", "desktop": 373, "mobile": 290},
        {"date": "Apr 06", "desktop": 301, "mobile": 340},
        {"date": "Apr 07", "desktop": 245, "mobile": 180},
        {"date": "Apr 08", "desktop": 409, "mobile": 320},
        {"date": "Apr 09", "desktop": 59, "mobile": 110},
        {"date": "Apr 10", "desktop": 261, "mobile": 190},
        {"date": "Apr 11", "desktop": 327, "mobile": 350},
        {"date": "Apr 12", "desktop": 292, "mobile": 210},
        {"date": "Apr 13", "desktop": 342, "mobile": 380},
        {"date": "Apr 14", "desktop": 137, "mobile": 220},
        {"date": "Apr 15", "desktop": 120, "mobile": 170},
        {"date": "Apr 16", "desktop": 138, "mobile": 190},
        {"date": "Apr 17", "desktop": 446, "mobile": 360},
        {"date": "Apr 18", "desktop": 364, "mobile": 410},
        {"date": "Apr 19", "desktop": 243, "mobile": 180},
        {"date": "Apr 20", "desktop": 89, "mobile": 150},
        {"date": "Apr 21", "desktop": 137, "mobile": 200},
        {"date": "Apr 22", "desktop": 224, "mobile": 170},
        {"date": "Apr 23", "desktop": 138, "mobile": 230},
        {"date": "Apr 24", "desktop": 387, "mobile": 290},
        {"date": "Apr 25", "desktop": 215, "mobile": 250},
        {"date": "Apr 26", "desktop": 75, "mobile": 130},
        {"date": "Apr 27", "desktop": 383, "mobile": 420},
        {"date": "Apr 28", "desktop": 122, "mobile": 180},
        {"date": "Apr 29", "desktop": 315, "mobile": 240},
        {"date": "Apr 30", "desktop": 454, "mobile": 380},
        {"date": "May 01", "desktop": 165, "mobile": 220},
        {"date": "May 02", "desktop": 293, "mobile": 310},
        {"date": "May 03", "desktop": 247, "mobile": 190},
        {"date": "May 04", "desktop": 385, "mobile": 420},
        {"date": "May 05", "desktop": 481, "mobile": 390},
        {"date": "May 06", "desktop": 498, "mobile": 520},
        {"date": "May 07", "desktop": 388, "mobile": 300},
        {"date": "May 08", "desktop": 149, "mobile": 210},
        {"date": "May 09", "desktop": 227, "mobile": 180},
        {"date": "May 10", "desktop": 293, "mobile": 330},
        {"date": "May 11", "desktop": 335, "mobile": 270},
        {"date": "May 12", "desktop": 197, "mobile": 240},
        {"date": "May 13", "desktop": 197, "mobile": 160},
        {"date": "May 14", "desktop": 448, "mobile": 490},
        {"date": "May 15", "desktop": 473, "mobile": 380},
        {"date": "May 16", "desktop": 338, "mobile": 400},
        {"date": "May 17", "desktop": 499, "mobile": 420},
        {"date": "May 18", "desktop": 315, "mobile": 350},
        {"date": "May 19", "desktop": 235, "mobile": 180},
        {"date": "May 20", "desktop": 177, "mobile": 230},
        {"date": "May 21", "desktop": 82, "mobile": 140},
        {"date": "May 22", "desktop": 81, "mobile": 120},
        {"date": "May 23", "desktop": 252, "mobile": 290},
        {"date": "May 24", "desktop": 294, "mobile": 220},
        {"date": "May 25", "desktop": 201, "mobile": 250},
        {"date": "May 26", "desktop": 213, "mobile": 170},
        {"date": "May 27", "desktop": 420, "mobile": 460},
        {"date": "May 28", "desktop": 233, "mobile": 190},
        {"date": "May 29", "desktop": 78, "mobile": 130},
        {"date": "May 30", "desktop": 340, "mobile": 280},
        {"date": "May 31", "desktop": 178, "mobile": 230},
        {"date": "Jun 01", "desktop": 178, "mobile": 200},
        {"date": "Jun 02", "desktop": 470, "mobile": 410},
        {"date": "Jun 03", "desktop": 103, "mobile": 160},
        {"date": "Jun 04", "desktop": 439, "mobile": 380},
        {"date": "Jun 05", "desktop": 88, "mobile": 140},
        {"date": "Jun 06", "desktop": 294, "mobile": 250},
        {"date": "Jun 07", "desktop": 323, "mobile": 370},
        {"date": "Jun 08", "desktop": 385, "mobile": 320},
        {"date": "Jun 09", "desktop": 438, "mobile": 480},
        {"date": "Jun 10", "desktop": 155, "mobile": 200},
        {"date": "Jun 11", "desktop": 92, "mobile": 150},
        {"date": "Jun 12", "desktop": 492, "mobile": 420},
        {"date": "Jun 13", "desktop": 81, "mobile": 130},
        {"date": "Jun 14", "desktop": 426, "mobile": 380},
        {"date": "Jun 15", "desktop": 307, "mobile": 350},
        {"date": "Jun 16", "desktop": 371, "mobile": 310},
        {"date": "Jun 17", "desktop": 475, "mobile": 520},
        {"date": "Jun 18", "desktop": 107, "mobile": 170},
        {"date": "Jun 19", "desktop": 341, "mobile": 290},
        {"date": "Jun 20", "desktop": 408, "mobile": 450},
        {"date": "Jun 21", "desktop": 169, "mobile": 210},
        {"date": "Jun 22", "desktop": 317, "mobile": 270},
        {"date": "Jun 23", "desktop": 480, "mobile": 530},
        {"date": "Jun 24", "desktop": 132, "mobile": 180},
        {"date": "Jun 25", "desktop": 141, "mobile": 190},
        {"date": "Jun 26", "desktop": 434, "mobile": 380},
        {"date": "Jun 27", "desktop": 448, "mobile": 490},
        {"date": "Jun 28", "desktop": 149, "mobile": 200},
        {"date": "Jun 29", "desktop": 103, "mobile": 160},
        {"date": "Jun 30", "desktop": 446, "mobile": 400},
    ]

    class AreaChart(rx.State):
        dataMap: dict[str, list[dict[str, str]]] = {
            "Last 3 months": data,
            "Last 30 days": data[-30:],
            "Last 7 days": data[-7:],
        }

        current_selection: list[dict[str, str]] = data

        @rx.event
        def change_data_time(self, value: str):
            self.current_selection = self.dataMap[value]

    return rx.center(
        rx.vstack(
            rx.hstack(
                info(
                    "Area Chart - Dynamic",
                    "3",
                    "Showing total visitors for the last 6 months",
                    "start",
                ),
                rx.select(
                    ["Last 3 months", "Last 30 days", "Last 7 days"],
                    default_value="Last 3 months",
                    on_change=AreaChart.change_data_time,
                ),
                align="center",
                justify="between",
                width="100%",
                wrap="wrap",
            ),
            rx.recharts.area_chart(
                rx.recharts.graphing_tooltip(**vars(tooltip_styles)),
                rx.recharts.cartesian_grid(
                    horizontal=True,
                    vertical=False,
                    fill_opacity=0.5,
                    stroke=rx.color("slate", 5),
                ),
                *[
                    rx.recharts.area(
                        data_key=name,
                        fill=ComponentWrapperState.default_theme[index],
                        stack_id="a",
                        stroke=ComponentWrapperState.default_theme[index + 1],
                    )
                    for index, name in enumerate(["desktop", "mobile"])
                ],
                rx.recharts.x_axis(
                    data_key="date",
                    axis_line=False,
                    min_tick_gap=32,
                    tick_size=10,
                    tick_line=False,
                    custom_attrs={"fontSize": "12px"},
                ),
                data=AreaChart.current_selection,
                width="100%",
                height=280,
            ),
            info(
                "Trending up by 5.2% this month",
                "2",
                "January - June 2024",
                "start",
            ),
            width="100%",
            margin_right="20px",
        ),
        width="100%",
        padding="0.5em",
    )



import reflex as rx

from ..style import Style
from ..style import Typography
from .style import ChatAreaStyle
from ..state import State


def chat_message(data: dict[str, str]):
    return rx.vstack(
        rx.text(data["role"], size="1", weight="bold", **Typography.passive),
        rx.text(
            data["message"],
            size="2",
            weight="medium",
            line_height="1.75em",
            **Typography.active,
        ),
        spacing="2",
        width="100%",
    )


def chat_box():
    return rx.vstack(
        # ... rx.vstack => chat history and chat session
        rx.vstack(
            #
            rx.foreach(State.chat_history, chat_message),
            **ChatAreaStyle.chat_session_style,
        ),
        chat_prompt(),
        **ChatAreaStyle.chat_box,
    )


def chat_prompt():
    return rx.hstack(
        rx.box(
            rx.input(value=State.prompt, on_change=State.set_prompt, width="100%"),
            width="100%",
        ),
        rx.button("send", on_click=State.send_prompt, loading=State.is_generating),
        width="100%",
        bottom="0",
        left="0",
        position="absolute",
        padding="1em 2em",
    )


def chat_area() -> rx.vstack:
    return rx.vstack(
        rx.badge(
            rx.text("Using Google's gemini-1.5-flash model.", size="1", weight="bold"),
            **ChatAreaStyle.model_tag,
        ),
        chat_box(),
        **Style.chat_area_base,
    )



from typing import Callable, List
from functools import wraps

import reflex as rx

from .style import BaseWrapperStyle

from .utils.routes import base_content_path_ui
from .utils.navigation import (
    pantry_in_page_navigation,
    charts_in_page_navigation,
    getting_started_in_page_navigation,
    blueprints_in_page_navigation,
)

from ...templates.sidemenu.sidemenu import sidemenu
from ...templates.footer.footer import footer, desktop_footer
from ...templates.wrapper.wrapper import baseWrapperHeader
from ...templates.navigation.navigation import docs_navigation
from ...templates.drawer.drawer import drawer


def base_footer_responsive(component: rx.Component, start: str, end: str):
    return rx.box(
        component,
        display=[start if i <= 3 else end for i in range(6)],
        width="100%",
    )


def base(url: str, page_name: str):

    def decorator(content: Callable[[], List[rx.Component]]):
        @wraps(content)
        def template():
            contents = content()
            return rx.hstack(
                *[
                    drawer(),
                    sidemenu(),
                    docs_navigation(),
                ],
                rx.vstack(
                    rx.vstack(
                        rx.divider(height="1em", opacity="0"),
                        baseWrapperHeader(base_content_path_ui(url), page_name),
                        rx.divider(height="1em", opacity="0"),
                        *contents,
                        rx.divider(height="2em", opacity="0"),
                        max_width="95%",
                        align="center",
                        **BaseWrapperStyle.content,
                    ),
                    pantry_in_page_navigation(url),
                    charts_in_page_navigation(url),
                    getting_started_in_page_navigation(url),
                    blueprints_in_page_navigation(url),
                    rx.vstack(
                        base_footer_responsive(desktop_footer(), "none", "flex"),
                        base_footer_responsive(footer(), "flex", "none"),
                        width="100%",
                        max_width="95%",
                        align="center",
                        padding="0.75em 0em",
                    ),
                    position="relative",
                    width="100%",
                    align="center",
                    height=["100%" if i == 0 else "100vh" for i in range(6)],
                    overflow=["" if i == 0 else "scroll" for i in range(6)],
                ),
                **BaseWrapperStyle.parent,
            )

        return template

    return decorator



from dataclasses import dataclass, field
from typing import Dict

import reflex as rx


@dataclass
class DashboardStatBarStyle:
    base: Dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "display": "grid",
            "grid_template_columns": [
                f"repeat({i}, minmax(0, 1fr))" for i in [1, 1, 2, 2, 2, 2]
            ],
            "padding": "1em",
            "row_gap": "1em",
            "column_gap": "1em",
        }
    )

    itemWrapper: Dict[str, str] = field(
        default_factory=lambda: {
            "height": "180px",
            "flex": "1 1 300px",
            "border_radius": "8px",
            "position": "relative",
            "padding": "1em",
            "background": rx.color("gray", 2),
            "border": f"1px solid {rx.color('gray', 4)}",
        }
    )


DashboardStatBarStyle: DashboardStatBarStyle = DashboardStatBarStyle()



from .bar.v1 import barchart_v1
from .bar.v2 import barchart_v2
from .bar.v3 import barchart_v3
from .bar.v4 import barchart_v4
from .bar.v5 import barchart_v5
from .bar.v6 import barchart_v6
from .bar.v7 import barchart_v7

from .area.v1 import areachart_v1
from .area.v2 import areachart_v2
from .area.v3 import areachart_v3
from .area.v4 import areachart_v4
from .area.v5 import areachart_v5
from .area.v6 import areachart_v6
from .area.v7 import areachart_v7

from .line.v1 import linechart_v1
from .line.v2 import linechart_v2
from .line.v3 import linechart_v3
from .line.v4 import linechart_v4
from .line.v5 import linechart_v5
from .line.v6 import linechart_v6
from .line.v7 import linechart_v7

from .pie.v1 import piechart_v1
from .pie.v2 import piechart_v2
from .pie.v3 import piechart_v3
from .pie.v4 import piechart_v4
from .pie.v5 import piechart_v5
from .pie.v6 import piechart_v6

from .radar.v1 import radar_v1
from .radar.v2 import radar_v2
from .radar.v3 import radar_v3
from .radar.v4 import radar_v4
from .radar.v5 import radar_v5
from .radar.v6 import radar_v6

from ..wrappers.component.wrapper import component_wrapper
from random import randint

import inspect

BASE_PATH: str = "https://github.com/LineIndent/buridan-ui/blob/main/buridan_ui/charts/"


def get_source(func) -> str:
    source: str = ""
    with open("buridan_ui/charts/style.py", "r") as file:
        source += file.read()
        source += "\n"
        source += inspect.getsource(func)

    return source


def create_export(func, directory, version, has_theme=True):
    @component_wrapper(f"{BASE_PATH}{directory}/v{version}.py", has_theme)
    def export():
        return [func(), get_source(func), randint(0, 100000)]

    return export


charts_exports_config = {
    "bar": [
        create_export(barchart_v1, "bar", 1),
        create_export(barchart_v2, "bar", 2),
        create_export(barchart_v3, "bar", 3),
        create_export(barchart_v4, "bar", 4),
        create_export(barchart_v5, "bar", 5),
        create_export(barchart_v6, "bar", 6),
        create_export(barchart_v7, "bar", 7),
    ],
    "area": [
        create_export(areachart_v1, "area", 1),
        create_export(areachart_v2, "area", 2),
        create_export(areachart_v3, "area", 3),
        create_export(areachart_v4, "area", 4),
        create_export(areachart_v5, "area", 5),
        create_export(areachart_v6, "area", 6),
        create_export(areachart_v7, "area", 7),
    ],
    "line": [
        create_export(linechart_v1, "line", 1),
        create_export(linechart_v2, "line", 2),
        create_export(linechart_v3, "line", 3),
        create_export(linechart_v4, "line", 4),
        create_export(linechart_v5, "line", 5),
        create_export(linechart_v6, "line", 6),
        create_export(linechart_v7, "line", 7),
    ],
    "pie": [
        create_export(piechart_v1, "pie", 1),
        create_export(piechart_v2, "pie", 2),
        create_export(piechart_v3, "pie", 3),
        create_export(piechart_v4, "pie", 4),
        create_export(piechart_v5, "pie", 5),
        create_export(piechart_v6, "pie", 6),
    ],
    "radar": [
        create_export(radar_v1, "radar", 1),
        create_export(radar_v2, "radar", 2),
        create_export(radar_v3, "radar", 3),
        create_export(radar_v4, "radar", 4),
        create_export(radar_v5, "radar", 5),
        create_export(radar_v6, "radar", 6),
    ],
}



import asyncio
from xml.etree import ElementTree as ET
import reflex as rx
import httpx

import google.generativeai as genai

import os


key = os.getenv("KEY")
genai.configure(api_key=key)

generation_config = {
    "temperature": 1,
    "top_p": 0.95,
    "top_k": 64,
    "max_output_tokens": 600,
    "response_mime_type": "text/plain",
}

model = genai.GenerativeModel(
    model_name="gemini-1.5-flash",
    generation_config=generation_config,
)

chat_session = model.start_chat()


class PubMedState(rx.State):
    user_query: str
    loader_txt: str

    is_processing: bool = False
    is_generating: bool = False

    articles: list[dict[str, str]]
    selection: list[dict[str, str]]

    summary: str

    async def generate_abstract_summary(self):
        if self.selection:
            self.is_generating = True
            yield
            abstracts = [
                item["abstract"] for item in self.selection if "abstract" in item
            ]
            message = f"Take the following abstracts and generate a summary based on them in markdown format: {abstracts}"
            response = chat_session.send_message(message)

            for word in response.text.split():
                for char in list(word):
                    self.summary += char
                    await asyncio.sleep(0.009)
                self.summary += " "
                yield

        else:
            yield rx.toast.error("No articles selected!")

        self.is_generating = False

    async def process_request(self):
        self.articles, self.selection, self.summary = [], [], ""
        self.is_processing = True
        self.loader_txt = f"Searching for articles related to '{self.user_query}'..."
        article_ids = await self.search_pubmed(self.user_query)
        yield
        await asyncio.sleep(2)
        if article_ids:
            self.loader_txt = f"Found {len(article_ids)} articles. Fetching details..."
            yield
            articles = await self.fetch_article_details(article_ids)
            for idx, article in enumerate(articles):
                self.articles.append(
                    {
                        "id": f"{idx + 1}",
                        "title": article["title"],
                        "date": article["pubdate"],
                        "url": article["url"],
                        "abstract": article["abstract"],
                    }
                )

        else:
            yield rx.toast.warning("No articles found.")

        self.is_processing = False

    async def search_pubmed(self, query, max_results=10):
        base_url = "https://eutils.ncbi.nlm.nih.gov/entrez/eutils/esearch.fcgi"
        params = {
            "db": "pubmed",
            "term": query,
            "retmode": "json",
            "retmax": max_results,
        }

        async with httpx.AsyncClient() as client:
            response = await client.get(base_url, params=params)
            if response.status_code == 200:
                result = response.json()
                return result["esearchresult"]["idlist"]
            else:
                print("Error:", response.status_code)
                return []

    async def fetch_article_details(self, pmids):
        base_url = "https://eutils.ncbi.nlm.nih.gov/entrez/eutils/efetch.fcgi"
        params = {
            "db": "pubmed",
            "id": ",".join(pmids),
            "retmode": "xml",
            "rettype": "abstract",
        }

        async with httpx.AsyncClient() as client:
            response = await client.get(base_url, params=params)

            if response.status_code == 200:
                root = ET.fromstring(response.content)

                articles = []
                for article in root.findall(".//PubmedArticle"):
                    title = article.findtext(".//ArticleTitle")
                    abstract = article.findtext(".//AbstractText")
                    pubdate = article.findtext(".//PubDate/Year")
                    pmid = article.findtext(".//PMID")
                    url = f"https://pubmed.ncbi.nlm.nih.gov/{pmid}/"

                    articles.append(
                        {
                            "title": title,
                            "abstract": abstract,
                            "pubdate": pubdate,
                            "url": url,
                        }
                    )
                return articles
            else:
                print("Error:", response.status_code)
                return []

    async def compile_selected_article(self, state: bool, identifier: str):
        article = next(
            (item for item in self.articles if item["id"] == identifier), None
        )
        if self.articles:
            article_copy = dict(article)
            if state:
                if not any(item["id"] == article_copy["id"] for item in self.selection):
                    self.selection.append(article_copy)  # Append a copy, not the proxy
            else:
                self.selection[:] = [
                    item for item in self.selection if item["id"] != identifier
                ]



from typing import Literal, Callable

import reflex as rx

# from ....states.routing import SiteRoutingState
from .style import LandingPageSectionWrapperStyle, LandingPageButtons

ButtonStyle = Literal["classic", "ghost", "outline", "soft", "solid", "surface"]
KeyDisplay = ["none" if i <= 2 else "flex" for i in range(6)]

button: Callable[[str, ButtonStyle], rx.Component] = lambda name, style: rx.button(
    rx.text(name, size="2", weight="medium"),
    variant=style,
    color_scheme="gray",
    **LandingPageButtons.base,
)

button_with_key: Callable[[str, str, str, ButtonStyle, callable], rx.Component] = (
    lambda tag, cmd, name, style, func: rx.button(
        rx.icon(tag=tag, size=18),
        rx.text(name, size="2", weight="bold"),
        rx.badge(
            rx.text(cmd),
            width="20px",
            height="20px",
            variant="soft",
            box_shadow="0px 2px 8px 0px rgba(0, 0, 0, 0.25)",
            display=KeyDisplay,
        ),
        on_click=func,
        variant=style,
        **LandingPageButtons.base,
    )
)


def landing_page_section_wrapper(
    badge: str,
    title: str,
    subtitle: str,
    link: str,
    path: str,
    components: list[rx.Component] = [],
) -> rx.vstack:
    return rx.vstack(
        # ... badge, title, subtitle, and link
        rx.vstack(
            # rx.badge(badge, variant="surface", size="1"),
            rx.heading(title, font_weight="900", size="8"),
            rx.text(subtitle, weight="medium", size="2"),
            rx.divider(height="1em", opacity="0"),
            rx.link(link, href=path, size="1"),
            **LandingPageSectionWrapperStyle.titles_secondary,
        ),
        *components,
        # ... wrapper style
        **LandingPageSectionWrapperStyle.wrapper_secondary,
    )


def landing_page_section_wrapper_main(title: str, subtitle: str) -> rx.vstack:
    return rx.vstack(
        # ... badge, title, subtitle, and link
        rx.vstack(
            rx.heading(
                title,
                font_weight="900",
                line_height="1em",
                font_size=["2.85em", "2.85em", "3em", "3em", "3.5em", "3.75em"],
            ),
            rx.text(subtitle, weight="medium", size="3"),
            rx.divider(height="1em", opacity="0"),
            rx.hstack(
                button("Explore Pantry", "soft"),
                button("View Source", "surface"),
                width="100%",
                max_width=["22em" if i >= 2 else "100%" for i in range(6)],
                display="grid",
                grid_template_columns=[
                    f"repeat({i}, minmax(0, 1fr))" for i in [1, 1, 2, 2, 2, 2]
                ],
            ),
            **LandingPageSectionWrapperStyle.titles,
        ),
        # ... wrapper style
        **LandingPageSectionWrapperStyle.wrapper,
    )


def blip(tag: str) -> rx.box:
    return rx.box(rx.icon(tag=tag, size=12), **LandingPageSectionWrapperStyle.blip)


def landing_page_features_wrapper(
    subtitle: str, title: str, tag: str, components: list[rx.Component] = []
) -> rx.hstack:
    return rx.hstack(
        rx.vstack(
            rx.vstack(
                rx.hstack(
                    blip(tag),
                    rx.text(title, size="3", font_weight="900"),
                ),
                rx.text(subtitle, size="4", weight="medium"),
                spacing="1",
            ),
            *components,
        ),
        **LandingPageSectionWrapperStyle.features,
    )



import reflex as rx
from .style import ComponentWrapperUtilStyle


def component_wrapper_source_code(path: str):
    return rx.button(
        rx.link(
            rx.icon(tag="github", size=14, color=rx.color("slate", 11)),
            href=path,
            is_external=True,
        ),
        border_radius="6px",
        display=["none" if i <= 1 else "flex" for i in range(6)],
        **ComponentWrapperUtilStyle.buttons,
    )



import reflex as rx
from ..style import Style, Typography


title: rx.Component = rx.text("getFit.", weight="bold", size="1", **Typography.active)
theme: rx.Component = rx.color_mode.button(size="1", **Typography.active)


def app_navigation_bar() -> rx.hstack:
    return rx.badge(
        rx.hstack(title, theme, **Style.navigation_child),
        **Style.navigation_parent,
    )



from dataclasses import dataclass, field
import reflex as rx


@dataclass
class ChangelogStyle:
    base: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "min_height": "100vh",
            "background": rx.color("gray", 2),
            "align": "center",
        }
    )

    header: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "height": "30vh",
            "max_width": "35em",
            "align": "start",
            "justify": "center",
            "padding": ["0px 24px" if i <= 2 else "0px 0px" for i in range(6)],
        },
    )

    content: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "max_width": "35em",
            "height": "100%",
            "justify": "end",
            "position": "relative",
            "padding": "1em 1em",
            "spacing": "8",
            "border_left": f"1px solid {rx.color('gray', 6)}",
        },
    )

    blip: dict[str, str] = field(
        default_factory=lambda: {
            "width": "24px",
            "height": "24px",
            "border_radius": "24px",
            "background": rx.color("gray", 3),
            "border": f"1.25px solid {rx.color('gray', 6)}",
            "position": "absolute",
            "left": "-11.5px",
            "align_items": "center",
            "justify_content": "center",
            "display": "flex",
        }
    )

    wrapper: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "align": "start",
            "justify": "start",
            "padding_left": "24px",
            "border_radius": "0px 5px 5px 0px",
        }
    )


ChangelogStyle: ChangelogStyle = ChangelogStyle()



from typing import Callable

import reflex as rx


title: Callable[[str], rx.Component] = lambda txt: rx.text(
    txt, size="2", weight="bold", color=rx.color("slate", 11)
)


wrapper: Callable[[str, list[rx.Component]], rx.Component] = (
    lambda txt, components: rx.vstack(
        title(txt), *components, spacing="2", width="100%"
    )
)



import reflex as rx

from .style import FooterStyle
from ...states.routing import SiteRoutingState


def create_footer_item(title: str, routes: list[dict[str, str]]):
    def item(data):
        return rx.hstack(
            rx.link(
                rx.text(
                    data["name"], size="1", weight="medium", color=rx.color("slate", 11)
                ),
                href=data["path"],
                text_decoration="none",
                on_click=SiteRoutingState.toggle_page_change(data),
            ),
            rx.cond(
                data["is_beta"],
                rx.badge("In Progress", color_scheme="orange"),
                rx.cond(
                    data["is_new"],
                    rx.badge("New", color_scheme="grass"),
                    rx.spacer(),
                ),
            ),
            width="100%",
            align="center",
        )

    return rx.vstack(
        rx.text(title, weight="bold", size="1", color=rx.color("slate", 12)),
        rx.hstack(rx.foreach(routes, item), **FooterStyle.footer_item),
        width="100%",
        padding="0.5em 0em",
        spacing="2",
    )


def footer():
    return rx.vstack(
        create_footer_item("Home", SiteRoutingState.GettingStartedRoutes),
        create_footer_item(
            "Interactive Applications", SiteRoutingState.InteractiveRoutes
        ),
        create_footer_item("Blueprint Templates", SiteRoutingState.BlueprintRoutes),
        create_footer_item("Charts UI", SiteRoutingState.ChartRoutes),
        create_footer_item("Pantry UI", SiteRoutingState.PantryRoutes),
        rx.divider(height="2em", opacity="0"),
        rx.vstack(
            rx.heading("buridan/ui", size="3", font_weight="900"),
            rx.text(
                "© 2024 Ahmad Hakim. All rights reserved.",
                size="1",
                weight="bold",
                color=rx.color("gray", 11),
            ),
            width="100%",
            spacing="2",
        ),
        **FooterStyle.base,
    )


def desktop_footer():
    return rx.vstack(
        rx.vstack(
            rx.heading("buridan/ui", size="3", font_weight="900"),
            rx.text(
                "© 2024 Ahmad Hakim. All rights reserved.",
                size="1",
                weight="medium",
                color=rx.color("slate", 11),
            ),
            spacing="2",
            width="100%",
        ),
        **FooterStyle.base,
    )



from typing import Callable, List
from dataclasses import dataclass, field

import reflex as rx


check = """
<svg class="shrink-0 mt-0.5 size-4 text-blue-600 dark:text-blue-500" xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"><polyline points="20 6 9 17 4 12"/></svg>
"""


freeSpecs = ["1 user", "Plan features", "Product & site support"]
startUpSpecs = [
    "Up to 5 users",
    "Access to premium features",
    "Email support",
    "Basic integrations",
]
teamSpecs = [
    "Up to 20 users",
    "Advanced features",
    "Priority email support",
    "Collaboration tools",
    "Team management features",
    "Advanced integrations",
]
enterpriseSpecs = [
    "Unlimited users",
    "All features included",
    "24/7 dedicated support",
    "Customizable integrations",
    "Advanced security features",
    "SLA support",
    "Onboarding assistance",
]


pricingHeader: Callable[[bool, str, str, str], rx.Component] = (
    lambda is_popular, name, price, subtitle: rx.vstack(
        rx.text(name, size="1", color=rx.color("slate", 11)),
        rx.heading(price, size="7", color=rx.color("slate", 12)),
        rx.text(subtitle, size="1", color=rx.color("slate", 11)),
        spacing="2",
        width="100%",
        align="center",
        text_align="center",
    )
)


pricingSpecs: Callable[[List[str]], rx.Component] = lambda specs: rx.vstack(
    *[
        rx.hstack(
            rx.html(check),
            rx.text(f"{spec}", size="1", weight="bold", color=rx.color("slate", 11)),
            align="center",
        )
        for spec in specs
    ],
    width="100%",
)

pricingButton: Callable[[str], rx.Component] = lambda style: rx.button(
    "Sign Up", width="100%", padding="0.75em", variant=style
)


tierStack: Callable[[bool, str, str, str, str, List[str]], rx.Component] = (
    lambda is_popular, name, price, subtitle, style, spec_list: rx.vstack(
        pricingHeader(is_popular, name, price, subtitle),
        rx.divider(height="1em", opacity="0"),
        pricingSpecs(spec_list),
        rx.divider(height="1em", opacity="0"),
        rx.spacer(),
        pricingButton(style),
        padding="1em",
        border=(
            f"1px solid {rx.color('gray', 4)}"
            if not is_popular
            else f"1px solid {rx.color('blue', 6)}"
        ),
        border_radius="8px",
        flex="1 1 200px",
        align="stretch",
        height="50vh",
    )
)


def pricing_v2():
    return rx.hstack(
        tierStack(
            False, "FREE", "Free", "No pricing. Forever free.", "outline", freeSpecs
        ),
        tierStack(
            True,
            "STARTUP",
            "39 USD",
            "All the basics for starting a new business.",
            "solid",
            startUpSpecs,
        ),
        tierStack(
            False,
            "TEAM",
            "59 USD",
            "Everything you need for a growing business.",
            "outline",
            startUpSpecs,
        ),
        tierStack(
            False,
            "ENTERPRISE",
            "199 USD",
            "Advanced features for scaling your business.",
            "outline",
            enterpriseSpecs,
        ),
        align="center",
        wrap="wrap",
        padding="1em",
        width="100%",
        min_height="60vh",
    )



import reflex as rx
from typing import Callable

from .style import DashboardAppStyle

from ..dashboard_components.sideBar.main import dashboardSidebar
from ..dashboard_components.navBar.main import dashboardNavbar
from ..dashboard_components.statBar.main import dashboardStatbar
from ..dashboard_components.trafficBar.main import dashboardTrafficbar
from ..dashboard_components.expenseBar.main import dashboardExpensebar
from ..dashboard_components.employeeTable.main import dashbaordEmployee

dashboardContentArea: Callable[[], rx.Component] = lambda: rx.vstack(
    dashboardNavbar(),
    dashboardStatbar(),
    rx.hstack(
        dashboardTrafficbar(),
        dashboardExpensebar(),
        **DashboardAppStyle.trafficAndExpenses,
    ),
    rx.box(dashbaordEmployee(), width="100%", padding="1em"),
    **DashboardAppStyle.contentArea,
)

# ... Main app function here ...
dashboardApp: Callable[[], rx.Component] = lambda: rx.hstack(
    # ... App side bar ...
    dashboardSidebar(),
    # ... App main content area ...
    dashboardContentArea(),
    # ... App style object ...
    **DashboardAppStyle.base,
)



import reflex as rx

from typing import Callable


blockTypeOne: Callable[[], rx.Component] = lambda: rx.hstack(
    *[
        rx.box(
            flex="1 1 200px",
            border_radius="8px",
            height="30vh",
            border=f"1px solid {rx.color('gray', 5)}",
            background=rx.color("gray", 3),
        )
        for _ in range(4)
    ],
    *[
        rx.box(
            flex="1 1 400px",
            border_radius="8px",
            height="30vh",
            border=f"1px solid {rx.color('gray', 5)}",
            background=rx.color("gray", 3),
        )
        for _ in range(4)
    ],
    *[
        rx.box(
            flex="1 1 200px",
            border_radius="8px",
            height="30vh",
            border=f"1px solid {rx.color('gray', 5)}",
            background=rx.color("gray", 3),
        )
        for _ in range(4)
    ],
    wrap="wrap",
    width="100%",
)



from typing import Callable

import reflex as rx


title: Callable[[str], rx.Component] = lambda name: rx.text(
    name, size="1", weight="bold", color=rx.color("slate", 11)
)


tip: Callable[[], rx.Component] = lambda: rx.icon(
    tag="info",
    size=20,
    color=rx.color("gray", 10),
    right="10px",
    position="absolute",
    cursor="help",
)

entry: Callable[[str], rx.Component] = lambda placeholder: rx.input(
    rx.tooltip(tip(), content="We store your data securely."),
    placeholder=placeholder,
    outline="none",
    variant="soft",
    width="100%",
    overflow="hidden",
    position="relative",
    display="flex",
    align_items="center",
    height="40px",
    background=rx.color("gray", 4),
)


def inputs_v3():
    return rx.vstack(
        title("Show tooltip on hover"),
        entry("Enter your email ..."),
        width="100%",
        max_width="25em",
        spacing="1",
    )



import reflex as rx

from .style import AppProfileWrapperStyle


def blip():
    return rx.box(
        rx.icon(tag="info", size=11, color=rx.color("slate", 10)),
        **AppProfileWrapperStyle.blip,
    )


def app_profile_item_wrapper(
    title: str, date: str, components: list[rx.Component] = []
):
    return rx.hstack(
        rx.vstack(
            rx.vstack(
                rx.hstack(
                    blip(),
                    rx.text(date, size="1", weight="bold", color=rx.color("slate", 10)),
                    align="center",
                ),
                rx.text(title, size="3", weight="bold", color=rx.color("slate", 11)),
                spacing="1",
            ),
            *components,
            width="100%",
        ),
        **AppProfileWrapperStyle.wrapper,
    )



from dataclasses import dataclass, field
from typing import Dict


@dataclass
class DashboardAppStyle:
    base: Dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "height": "100vh",
            "spacing": "0",
            "overscroll_behavior": "none",
        }
    )

    contentArea: Dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "height": "100%",
            "position": "relative",
            "overflow": "scroll",
            "spacing": "2",
        }
    )

    trafficAndExpenses: Dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "height": "100%",
            "display": "grid",
            "grid_template_columns": [
                f"repeat({i}, minmax(0, 1fr))" for i in [1, 1, 1, 1, 3, 3]
            ],
            "padding": "1em",
            "row_gap": "1em",
            "column_gap": "1em",
        }
    )


DashboardAppStyle: DashboardAppStyle = DashboardAppStyle()



import reflex as rx


def tab_menu_wrapper(name: str, value: str):
    return rx.tabs.trigger(
        rx.text(name),
        value=value,
        cursor="pointer",
        color=rx.color("slate", 12),
        flex="1",
    )


def component_wrapper_tab_menu() -> rx.tabs.list:
    return rx.tabs.list(
        tab_menu_wrapper("Preview", "1"),
        tab_menu_wrapper("Code", "2"),
        justify_content="start",
        align_items="center",
    )


def component_wrapper_tab_menu_blueprints() -> rx.tabs.list:
    return rx.tabs.list(
        tab_menu_wrapper("Preview", "1"),
        tab_menu_wrapper("Front End", "2"),
        tab_menu_wrapper("Style Sheet", "3"),
        tab_menu_wrapper("State Vars", "4"),
        justify_content="center",
        align_items="center",
        margin="0.5em 0.15em",
    )



import reflex as rx


design = ["Figma", "Sketch"]
development = ["HTML", "CSS", "Tailwind CSS", "React", "Vue"]
collaboration = ["Mailchimp", "Slack", "Notion"]
expertise = [
    "UI/UX Design",
    "Design Systems",
    "Custom Illustrations",
    "Responsive Design",
]
skills = [
    "Strong communication",
    "Problem-solving",
    "Attention to detail",
    "Time management",
]


def create_list_item(title: str, items: list[str]):
    return rx.hstack(
        rx.text(title, weight="medium", color=rx.color("slate", 11), size="1"),
        rx.hstack(
            *[
                rx.text(item, weight="bold", color=rx.color("slate", 12), size="1")
                for item in items
            ],
            justify="start",
            wrap="wrap",
            spacing="2",
            width="100%",
            max_width="20em",
        ),
        justify="between",
        wrap="wrap",
        width="100%",
        max_width="30em",
        spacing="2",
    )


def lists_v1():

    return rx.vstack(
        create_list_item("Design Tools:", design),
        create_list_item("Development:", development),
        create_list_item("Collaboration:", collaboration),
        create_list_item("Design Expertise:", expertise),
        create_list_item("Soft Skills:", skills),
        width="100%",
        align="center",
        justify="center",
    )



from typing import Callable, Optional

import reflex as rx

from .state import PubMedState
from .style import PubMedStyle

from .wrappers.item import wrapper

txt_overflow = {
    "white_space": "nowrap",
    "overflow": "hidden",
    "text_overflow": "ellipsis",
    "cursor": "pointer",
}

user_query: Callable[[], rx.Component] = lambda: rx.input(
    value=PubMedState.user_query,
    width="100%",
    on_change=PubMedState.set_user_query,
)


button: Callable[[str, str, Optional], rx.Component] = (
    lambda name, color, kwargs=None: rx.button(
        name,
        color_scheme=color,
        variant="surface",
        cursor="pointer",
        width="100%",
        **(kwargs if kwargs else {}),
    )
)

loader_txt: Callable[[], rx.Component] = lambda: rx.text(
    PubMedState.loader_txt, size="2", color=rx.color("slate", 11), padding="1em 0em"
)

hover: Callable[[str], rx.Component] = lambda txt: rx.hover_card.root(
    rx.hover_card.trigger(
        rx.text(txt, width="300px", **txt_overflow),
    ),
    rx.hover_card.content(rx.text(txt)),
)

table: Callable[[], rx.Component] = lambda: rx.table.root(
    rx.table.header(
        rx.table.row(
            rx.foreach(
                ["", "ID", "Title", "Date", "URL", "Abstract"],
                lambda title: rx.table.column_header_cell(
                    rx.text(title, font_size="12px", weight="bold"),
                ),
            )
        ),
    ),
    rx.table.body(
        rx.foreach(
            PubMedState.articles,
            lambda article: rx.table.row(
                rx.table.cell(
                    rx.checkbox(
                        on_change=lambda _: PubMedState.compile_selected_article(
                            _, article["id"]
                        )
                    )
                ),
                rx.table.cell(article["id"]),
                rx.table.cell(hover(article["title"])),
                rx.table.cell(article["date"]),
                rx.table.cell(rx.link(article["url"], href=article["url"])),
                rx.table.cell(hover(article["abstract"])),
                align="center",
                white_space="nowrap",
            ),
        ),
        transition="all 550ms ease",
    ),
    width="100%",
    variant="surface",
    size="2",
)


def pubmed_ai():
    return rx.vstack(
        wrapper(
            "1. Enter a health topic you're interested in",
            [
                rx.vstack(
                    user_query(),
                    button(
                        "Send",
                        "blue",
                        {
                            "on_click": rx.event(PubMedState.process_request),
                            "loading": PubMedState.is_processing,
                        },
                    ),
                    width="100%",
                    max_width="25em",
                ),
            ],
        ),
        loader_txt(),
        rx.cond(
            PubMedState.articles,
            wrapper(
                f"2. Table Results for query",
                [rx.box(table(), width="100%")],
            ),
            rx.spacer(),
        ),
        rx.divider(height="1em", opacity="0"),
        rx.cond(
            PubMedState.selection,
            wrapper(
                f"3. Generate Summary for Selected Articles",
                [
                    button(
                        "Generate",
                        "blue",
                        {
                            "max_width": "25em",
                            "loading": PubMedState.is_generating,
                            "on_click": rx.event(PubMedState.generate_abstract_summary),
                        },
                    )
                ],
            ),
            rx.spacer(),
        ),
        rx.divider(height="1em", opacity="0"),
        rx.cond(
            PubMedState.summary,
            wrapper(
                f"4. Summary of Abstracts",
                [rx.text(PubMedState.summary, size="3", color=rx.color("slate", 12))],
            ),
            rx.spacer(),
        ),
        **PubMedStyle.base,
    )



import reflex as rx

from .wrappers.base.main import base

from .routes.routes import Routes

from .pages.landing.hero import landing_page
from .charts.exports import charts_exports_config
from .pantry.exports import pantry_exports_config
from .blueprints.exports import blueprint_export_config
from .pages.interactive.exports import interactive_config
from .pages.charts_landing.main import charts_landing_page

from .pages.started_items.exports import getting_started_config

from .sandbox.main import buridan_sandbox
from .sandbox.state import Editor

AppFontURL: str = (
    "https://fonts.googleapis.com/css2?family=Inter:wght@100;200;300;400;500;600;700;800;900&display=swap"
)

app = rx.App(
    stylesheets=[AppFontURL],
    style={
        "background": "transparent",
        rx.heading: {"font_family": "inter"},
        rx.text: {"font_family": "inter"},
    },
)


def get_exports(directory: str, config_file: dict[str, list[callable]]):
    return [export() for export in config_file[directory]]


def add_routes(
    routes: list[dict[str, str]],
    export_config: dict[str, list[callable]],
):
    for route in routes:

        @base(route["path"], route["name"])
        def export_page() -> callable:
            if route["name"] == "Standard Tables":
                return get_exports(route["dir"], export_config)[1:]
            elif route["name"] == "Table Pagination":
                return get_exports(route["dir"], export_config)[:1]
            return get_exports(route["dir"], export_config)

        app.add_page(
            export_page(), route=route["path"], title=f"{route['name']} - Buridan UI"
        )


# ... set the DEV var to True for faster hot reload
# ... ... change the ENV to match the page in progress
DEV: bool = False

if DEV:
    # ... ex: working with X item Y -> set the ENV data as such:
    ENV = {
        "path": "/charts/area-charts",
        "name": "Area Charts",
        "dir": "area",
        "config": charts_exports_config,
    }

    @base(ENV["path"], ENV["name"])
    def __() -> callable:
        return [export() for export in ENV["config"][ENV["dir"]]]

else:
    app.add_page(landing_page(), route="/", title="Buridan UI")
    app.add_page(charts_landing_page(), route="/charts/ui")
    add_routes(Routes.interactive, interactive_config)
    add_routes(Routes.blueprints, blueprint_export_config)
    add_routes(Routes.pantries, pantry_exports_config)
    add_routes(Routes.charts, charts_exports_config)
    add_routes(Routes.started, getting_started_config)

    # EXPERIMENTAL:
    app.add_page(
        buridan_sandbox(), route="/buridan-sandbox", on_load=Editor.automatic_reload
    )



import os
from collections import defaultdict
from typing import List, Dict

from ...templates.thumbnail.thumbnail import pantry_thumbnail
from ...routes.routes import PantryRoutes


def get_svg_files(
    base_url: str = "https://raw.githubusercontent.com/LineIndent/buridan-ui/main/assets/thumbnails",
) -> List[Dict[str, str]]:

    svg_files = [
        os.path.basename(directory)
        for directory, _, _ in os.walk("buridan_ui/pantry")
        if os.path.basename(directory) not in {"pantry", "__pycache__"}
    ]

    return sorted(
        [{"image": f"{base_url}/{f}.svg", "filename": f"{f}.svg"} for f in svg_files],
        key=lambda x: x["filename"],
    )


def get_component_quantities(
    pantry_folder: str = "buridan_ui/pantry",
) -> Dict[str, int]:
    quantities = defaultdict(int)
    for subdir, _, files in os.walk(pantry_folder):
        if os.path.basename(subdir) not in {"pantry", "__pycache__"}:
            quantities[os.path.basename(subdir)] = len(files)
    return dict(quantities)


def get_pantry_items() -> List[Dict[str, str]]:
    return [item for item in PantryRoutes if item["name"] != "Table Pagination"]


NORMALIZATION_MAP = {
    # ... key name == PANTRY_ROUTE[name]: value name == Pantry dir names
    "Animations": "animations",
    "Backgrounds": "backgrounds",
    "Cards": "cards",
    "Frequently Asked Questions": "faq",
    "Descriptive Lists": "lists",
    "Featured": "featured",
    "Logins": "logins",
    "Menus": "menus",
    "Onboarding & Progress": "onboardings",
    "Payments & Billing": "payments",
    "Popups": "popups",
    "Pricing Sections": "pricing",
    "Prompt Boxes": "prompts",
    "Subscribe": "subscribe",
    "Standard Forms": "forms",
    "Standard Tables": "tables",
    "Timeline": "timeline",
    "Footers": "footers",
    "Inputs": "inputs",
}


def combine_items(
    svg_files: List[Dict[str, str]],
    quantity_map: Dict[str, int],
    pantry_items: List[Dict[str, str]],
) -> List[Dict[str, str]]:
    combined_items = []
    for pantry_item in pantry_items:
        filename_key = NORMALIZATION_MAP.get(pantry_item["name"])
        quantity = quantity_map.get(filename_key, 0)
        corresponding_image = next(
            (
                svg["image"]
                for svg in svg_files
                if svg["filename"].startswith(filename_key)
            ),
            None,
        )

        combined_items.append(
            {
                "image": corresponding_image,
                "quantity": quantity,
                "name": pantry_item["name"],
                "path": pantry_item["path"],
            }
        )
    return combined_items


def create_thumbnails(combined_items: List[Dict[str, str]]) -> List[str]:

    return [
        pantry_thumbnail(
            item["path"], item["image"], item["name"], str(item["quantity"])
        )
        for item in combined_items
    ]


def main():
    svg_files = get_svg_files()
    quantity_map = get_component_quantities()
    pantry_items = get_pantry_items()
    combined_items = combine_items(
        svg_files,
        quantity_map,
        pantry_items,
    )
    thumbnails = create_thumbnails(combined_items)
    return thumbnails


export_thumbnail = main()



import reflex as rx
from ...wrappers.base import main
from ...pantry.timeline.v1 import blip


def wrapper(title: str, instructions: str, components=None, **kwargs):
    if components is None:
        components = []
    return rx.hstack(
        rx.vstack(
            rx.vstack(
                rx.hstack(
                    blip(),
                    rx.text(
                        title, size="2", weight="medium", color=rx.color("slate", 11)
                    ),
                    align="center",
                ),
                rx.text(
                    instructions, size="3", weight="bold", color=rx.color("slate", 12)
                ),
                width="100%",
                spacing="1",
            ),
            *components,
            width="100%",
        ),
        width="100%",
        align="start",
        justify="start",
        padding_left="15px",
        border_radius="0px 5px 5px 0px",
        **kwargs,
    )


def create_code_line(code_string: str):
    return rx.hstack(
        rx.code_block(
            code_string,
            width="100%",
            font_size="13px",
            language="markup",
            wrap_long_lines=True,
            scrollbar_width="none",
            code_tag_props={"pre": "transparent"},
            custom_style={"color": rx.color("gray", 12)},
        ),
        rx.button(
            rx.icon(tag="file", size=15),
            color_scheme="gray",
            variant="ghost",
            size="2",
            on_click=[
                # rx.toast.provider("Code copied!"),
                rx.set_clipboard(code_string),
            ],
            cursor="pointer",
            position="absolute",
            right="2%",
        ),
        width="100%",
        align="center",
        position="relative",
    )


def installation():
    return rx.box(
        rx.vstack(
            wrapper(
                "Step 1: Check your Python version",
                "To use Reflex you need to have Python version 3.9 or above installed on your system.",
                [create_code_line("python3 --version")],
            ),
            wrapper(
                "Step 2: PIP install the Reflex framework",
                "Use the following command to install Reflex:",
                [
                    create_code_line("pip3 install reflex"),
                    rx.text(
                        "Male sure the latest version of Reflex is installed",
                        size="3",
                        weight="bold",
                        color=rx.color("slate", 12),
                    ),
                    create_code_line("reflex --version"),
                ],
            ),
            wrapper(
                "Step 3: Create a new Reflex Web Application",
                "Inside your root directory, run the following command to create a new app:",
                [create_code_line("reflex init")],
            ),
            wrapper(
                "Step 4: Copy & paste a pantry item directly into your app",
                "You can now easily integrate pantry pantry within your app and personalize them.",
            ),
            max_width="50em",
            width="100%",
            spacing="9",
            position="relative",
            border_left=f"1px solid {rx.color('gray')}",
        ),
        width="100%",
        display="flex",
        justify_content="center",
        padding="0px 14px",
    )



import reflex as rx


def popups_v2():
    return rx.center(
        rx.dialog.root(
            rx.dialog.trigger(
                rx.button(
                    "Open Dialog",
                    variant="surface",
                    color_scheme="gray",
                    cursor="pointer",
                )
            ),
            rx.dialog.content(
                rx.hstack(
                    rx.text(
                        "Need more help?",
                        size="4",
                        weight="bold",
                        color=rx.color("slate", 11),
                    ),
                    justify="center",
                    padding="15px 0px 5px 0px",
                ),
                rx.vstack(
                    rx.vstack(
                        rx.button(
                            "Message Us",
                            radius="full",
                            padding="20px",
                            width="100%",
                            variant="surface",
                            cursor="pointer",
                        ),
                        rx.button(
                            "Live Chat",
                            radius="full",
                            padding="20px",
                            width="100%",
                            variant="surface",
                            color_scheme="gray",
                            cursor="pointer",
                        ),
                        rx.text(
                            "● Chat Online",
                            color_scheme="grass",
                            size="1",
                            weight="medium",
                            align="center",
                        ),
                        width="100%",
                        padding="10px 10px",
                        align="center",
                    ),
                    rx.divider(),
                    rx.hstack(
                        *[
                            rx.center(
                                rx.icon(tag=tag, size=15),
                                width="35px",
                                height="35px",
                                border_radius="35px",
                                border="1px solid gray",
                            )
                            for tag in ["github", "twitter", "facebook"]
                        ],
                        align="center",
                        justify="center",
                        width="100%",
                        spacing="5",
                        padding="10px",
                    ),
                    align="center",
                    padding="5px 0px",
                ),
                width="320px",
                padding="0px",
            ),
        ),
        height="25vh",
    )



from dataclasses import dataclass, field
from typing import Dict

import reflex as rx


@dataclass
class LayoutStyleSheet:

    navigation: Dict[str, str] = field(
        default_factory=lambda: {
            "top": "0",
            "left": "0",
            "width": "100%",
            "align": "center",
            "justify": "between",
            "position": "sticky",
            "padding": "1.25em 2em",
            "background": rx.color("gray", 3),
        }
    )

    singleColumn: Dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "height": "100vh",
            "position": "relative",
            "overflow": "scroll",
        }
    )

    doubleColumn: Dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "height": "100vh",
            "overscroll_behavior": "none",
            "position": "relative",
        }
    )

    doubleColumnContentArea: Dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "height": "100%",
            "position": "relative",
            "overflow": "scroll",
            "spacing": "2",
            "background": rx.color("gray", 1),
        }
    )

    doubleColumnLeft: Dict[str, str] = field(
        default_factory=lambda: {
            "top": "0",
            "left": "0",
            "spacing": "5",
            "width": "320px",
            "max_width": "320px",
            "height": "100vh",
            "position": "sticky",
            "padding": "2em 1.5em",
            "background": rx.color("gray", 3),
            "border_right": f"1px solid {rx.color('gray', 4)}",
            "display": ["none" if i <= 4 else "flex" for i in range(6)],
        }
    )


LayoutStyleSheet: LayoutStyleSheet = LayoutStyleSheet()



import reflex as rx
from reflex.constants.colors import Color
from typing_extensions import Callable

from .style import NavigationStyle
from ...templates.drawer.state import DrawerState
from ...states.routing import SiteRoutingState


nav_icon: Callable[[rx.Component], rx.badge] = lambda component: rx.badge(
    component,
    color_scheme="gray",
    variant="soft",
    width="21px",
    height="21px",
    display="flex",
    align_items="center",
    justify_content="center",
    background="none",
)

theme = nav_icon(
    rx.el.button(
        rx.color_mode.icon(
            light_component=rx.icon(
                "moon",
                size=14,
                color=rx.color("slate", 12),
            ),
            dark_component=rx.icon(
                "sun",
                size=14,
                color=rx.color("slate", 12),
            ),
        ),
        on_click=rx.toggle_color_mode,
    )
)

github = nav_icon(
    rx.link(
        rx.icon(
            tag="github",
            size=14,
            color=rx.color("slate", 12),
        ),
        href="https://github.com/LineIndent/buridan-ui",
        display=["none", "none", "none", "none", "flex", "flex"],
    ),
)


def navigation_links(data: dict[str, str | Color]):
    return rx.link(
        rx.text(data["name"], size="1", weight="medium", color=rx.color("slate", 12)),
        href=data["path"],
        text_decoration="none",
        on_click=SiteRoutingState.toggle_page_change(data),
    )


def navigation_right_side_items():
    return rx.hstack(
        rx.hstack(github, theme, align="center", spacing="2"),
        rx.el.button(
            rx.icon(tag="align-right", size=15),
            on_click=DrawerState.toggle_drawer,
            size="1",
            variant="ghost",
            color_scheme="gray",
            cursor="pointer",
            display=["flex", "flex", "flex", "flex", "none", "none"],
        ),
        align="center",
    )


def navigation_left_side_items():
    return rx.hstack(
        rx.image(src="/logo.jpg", **NavigationStyle.logo),
        rx.heading(
            "buridan/ui",
            font_size="0.9em",
            font_weight="800",
            cursor="pointer",
            on_click=[
                SiteRoutingState.toggle_page_change({"name": "Home", "path": "/"}),
                rx.redirect("/"),
            ],
        ),
        rx.divider(width="0.75em", opacity="0"),
        rx.hstack(
            rx.foreach(SiteRoutingState.NavigationRoutes, navigation_links),
            display=["none", "none", "none", "none", "flex", "flex"],
            align="center",
        ),
        align="center",
        spacing="2",
    )


def navigation():
    return rx.hstack(
        navigation_left_side_items(),
        navigation_right_side_items(),
        **NavigationStyle.base,
    )


def docs_navigation():
    return rx.hstack(
        rx.hstack(
            rx.image(src="/logo.jpg", **NavigationStyle.logo),
            rx.heading(
                "buridan/ui",
                font_size="0.9em",
                font_weight="800",
                cursor="pointer",
                on_click=[
                    SiteRoutingState.toggle_page_change({"name": "Home", "path": "/"}),
                    rx.redirect("/"),
                ],
            ),
            align="center",
        ),
        rx.hstack(
            rx.hstack(github, theme, align="center", spacing="2"),
            rx.el.button(
                rx.icon(
                    tag="align-right",
                    size=15,
                    cursor="pointer",
                ),
                on_click=DrawerState.toggle_drawer,
                size="1",
                variant="soft",
                color_scheme="gray",
                cursor="pointer",
                display=["flex", "flex", "flex", "flex", "none", "none"],
            ),
            align="center",
        ),
        **NavigationStyle.base,
    )


def landing_page_navigation():
    return rx.hstack(
        navigation_left_side_items(),
        navigation_right_side_items(),
        **NavigationStyle.landing_page_nav,
    )



import reflex as rx

from ..style import tooltip_styles, info
from ...wrappers.state import ComponentWrapperState

from typing import Any

def linechart_v1(
    data: rx.Var[list[dict[str, Any]]],
    x: rx.Var[str],
    y: rx.Var[str] | rx.Var[list[str]] | None = None,
    x_label: rx.Var[str] | None = None,
    # y_label: rx.Var[str] | None = None,
    # color: rx.Var[str] | None = None,
    # horizontal: rx.Var[bool] = False,
    # height: rx.Var[int] = rx.Var.create(250),
):
    """Graph data in a line chart.

    Example usage:
    class State(rx.State):
        # INCLUDE FULL TYPE ANNOTATION!
        data: list[dict[str, Any]] = [
            {"name": "John", "age": 30, "city": "New York"},
        ]
    ...

    # Always prefer to hook up to state!
    linechart_v1(data=State.data, x="name", y=["age"], x_label="Name")
    """

    return rx.center(
        rx.vstack(
            rx.recharts.line_chart(
                rx.recharts.graphing_tooltip(
                    **vars(tooltip_styles),
                    custom_attrs={"display": "flex", "justify-content": "space-between"}
                ),
                rx.recharts.cartesian_grid(
                    horizontal=True,
                    vertical=False,
                    fill_opacity=0.5,
                    stroke=rx.color("slate", 5),
                ),
                rx.foreach(
                    y,
                    lambda name, index: rx.recharts.line(
                        data_key=name,
                        stroke=ComponentWrapperState.default_theme[index],
                        type_="natural",
                        dot=False,
                    ),
                ),
                rx.recharts.x_axis(
                    data_key=x,
                    label=x_label,
                    axis_line=False,
                    tick_size=10,
                    tick_line=False,
                    custom_attrs={"fontSize": "12px"},
                ),
                data=data,
                width="100%",
                height=250,
                margin={"left": 20},
            ),
            width="100%",
            margin_right="20px",
        ),
        width="100%",
        padding="0.5em",
    )



from dataclasses import dataclass, field
import reflex as rx


@dataclass
class BlueprintWrapperStyle:
    root: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "padding": "2px",
            "overflow": "hidden",
            "default_value": "1",
            "border_radius": "10px",
            "background": rx.color("gray", 3),
        }
    )

    preview: dict[str, str] = field(
        default_factory=lambda: {
            "overflow": "hidden",
            "padding": "24px 12px",
            "align_items": "center",
            "border_radius": "10px",
            "justify_content": "center",
            "background": rx.color("gray", 2),
        }
    )


BlueprintWrapperStyle: BlueprintWrapperStyle = BlueprintWrapperStyle()



import reflex as rx

from buridan_ui.wrappers.state import ComponentWrapperState
from .style import ComponentWrapperUtilStyle

IconMap = {"100%": "monitor", "60%": "tablet", "30%": "smartphone"}
PaddingMap = {0: "6px 0px 0px 6px", 1: "0px", 2: "0px 6px 6px 0px"}


def _(index: int, icon: str, resize: str, idd: int):
    return rx.hover_card.root(
        rx.hover_card.trigger(
            rx.button(
                rx.icon(
                    tag=icon,
                    size=20,
                    color=rx.color("slate", 11),
                    transform="scale(1.3)",
                ),
                border_radius=PaddingMap[index],
                on_click=ComponentWrapperState.resize(idd, resize),
                **ComponentWrapperUtilStyle.buttons,
            ),
        ),
        rx.hover_card.content(
            rx.text(
                icon if icon != "smartphone" else "mobile",
                size="1",
                color=rx.color("slate", 12),
                weight="bold",
            ),
            padding="10px",
            border_radius="6px",
        ),
    )


def component_wrapper_responsive_menu(idd: int) -> rx.hstack:
    return rx.hstack(
        *[
            _(index, IconMap[resize], resize, idd)
            for index, resize in enumerate(["30%", "60%", "100%"])
        ],
        spacing="0",
        align="center",
        display=["none" if i <= 3 else "flex" for i in range(6)],
    )


def component_wrapper_responsive_menu_hero(idd: int) -> rx.hstack:
    return rx.hstack(
        *[
            _(index, IconMap[resize], resize, idd)
            for index, resize in enumerate(["30%", "60%", "100%"])
        ],
        spacing="0",
        align="center",
    )



import reflex as rx


class Table(rx.State):
    data: list[dict[str, str]] = [
        {
            "avatar": "https://raw.githubusercontent.com/mantinedev/mantine/master/.demo/avatars/avatar-1.png",
            "name": "Robert Wolfkisser",
            "job": "Engineer",
            "email": "rob_wolf@gmail.com",
            "rate": "22",
        },
        {
            "avatar": "https://raw.githubusercontent.com/mantinedev/mantine/master/.demo/avatars/avatar-5.png",
            "name": "Jill Jailbreaker",
            "job": "Engineer",
            "email": "jj@breaker.com",
            "rate": "45",
        },
        {
            "avatar": "https://raw.githubusercontent.com/mantinedev/mantine/master/.demo/avatars/avatar-3.png",
            "name": "Henry Silkeater",
            "job": "Designer",
            "email": "henry@silkeater.io",
            "rate": "76",
        },
        {
            "avatar": "https://raw.githubusercontent.com/mantinedev/mantine/master/.demo/avatars/avatar-3.png",
            "name": "Bill Horsefighter",
            "job": "Designer",
            "email": "bhorsefighter@gmail.com",
            "rate": "15",
        },
        {
            "avatar": "https://raw.githubusercontent.com/mantinedev/mantine/master/.demo/avatars/avatar-2.png",
            "name": "Jeremy Footviewer",
            "job": "Manager",
            "email": "jeremy@foot.dev",
            "rate": "98",
        },
    ]


def create_sidebar_menu_item(name: str, tag: str, color: str):
    return rx.hstack(
        rx.icon(tag=tag, size=14),
        rx.text(name, font_size="11px", color_scheme="gray"),
        color=color,
        width="100%",
        justify="start",
        align="center",
    )


def sidebar_item_option_menu():
    return rx.menu.root(
        rx.menu.trigger(
            rx.icon(tag="ellipsis", size=14, cursor="pointer"),
        ),
        rx.menu.content(
            rx.menu.item(
                create_sidebar_menu_item(
                    "Send message",
                    "mails",
                    "inherit",
                )
            ),
            rx.menu.item(
                create_sidebar_menu_item(
                    "Add note",
                    "notepad-text",
                    "inherit",
                )
            ),
            rx.menu.item(
                create_sidebar_menu_item(
                    "Terminate Contract",
                    "trash-2",
                    "red",
                )
            ),
            size="1",
        ),
    )


def create_data_row(data: dict[str, str]):
    return rx.table.row(
        rx.table.cell(
            rx.hstack(
                rx.avatar(src=data["avatar"], size="2", radius="full"),
                rx.vstack(
                    rx.text(
                        data["name"],
                        font_size="12px",
                        weight="medium",
                    ),
                    rx.text(
                        data["job"],
                        color_scheme="gray",
                        font_size="10px",
                        weight="medium",
                    ),
                    spacing="0",
                ),
                align="center",
            ),
        ),
        rx.table.cell(
            rx.vstack(
                rx.text(data["email"], font_size="12px"),
                rx.text("Email", color_scheme="gray", font_size="10px"),
                spacing="0",
            )
        ),
        rx.table.cell(
            rx.vstack(
                rx.text(f"${data['rate']}.0/h", font_size="12px"),
                rx.text("Rate", font_size="10px", color_scheme="gray"),
                spacing="0",
            )
        ),
        rx.table.cell(
            rx.hstack(
                rx.button(
                    rx.icon(tag="pencil", size=13, color="gray"),
                    variant="ghost",
                    cursor="pointer",
                ),
                sidebar_item_option_menu(),
            ),
        ),
        width="100%",
        align="center",
        white_space="nowrap",
    )


def tables_v3():
    return rx.table.root(
        rx.table.body(
            rx.foreach(Table.data, create_data_row),
        ),
        width="100%",
        variant="surface",
        max_width="800px",
        size="2",
    )



import reflex as rx
from typing import Callable

from .style import DashboardTrafficBarStyle

trafficDataSet = {
    0: {"color": "blue", "title": "github.com", "qty": 132},
    1: {"color": "purple", "title": " accounts.google.com ", "qty": 32},
    2: {"color": "teal", "title": "discord.app", "qty": 54},
    3: {"color": "orange", "title": "twitter.com", "qty": 23},
    4: {"color": "gray", "title": "Others", "qty": 16},
}

trafficQuantitySum = sum(entry["qty"] for entry in trafficDataSet.values())
trafficDataSet = {
    key: {**entry, "percent": (entry["qty"] / trafficQuantitySum) * 100}
    for key, entry in trafficDataSet.items()
}


trafficMenuTitle: Callable[[], rx.heading] = lambda: rx.heading(
    "Referral Traffic", size="2", color=rx.color("slate", 12), weight="bold"
)

trafficMenuQuantity: Callable[[], rx.hstack] = lambda: rx.hstack(
    *[
        rx.box(
            width=f"{entry['percent']}%",
            height="10px",
            bg=rx.color(entry["color"]),
            border_radius=(
                "10px 0 0 10px"
                if idx == 0
                else "0 10px 10px 0" if idx == len(trafficDataSet) - 1 else "0"
            ),
        )
        for idx, entry in enumerate(trafficDataSet.values())
    ],
    spacing="1",
    align="center",
    width="100%",
)


trafficMenuItem: Callable[[str, str, str], rx.hstack] = (
    lambda color, title, qty: rx.hstack(
        rx.hstack(
            rx.box(
                width="8px",
                height="8px",
                border_radius="8px",
                background=rx.color(color),
            ),
            rx.text(title, size="1", weight="bold", color=rx.color("slate", 12)),
            align="center",
            spacing="2",
        ),
        rx.text(f"{qty}k", size="1", weight="bold", color=rx.color("slate", 11)),
        align="center",
        justify="between",
        width="100%",
    )
)


dashboardTrafficbar: Callable[[], rx.vstack] = lambda: rx.vstack(
    rx.hstack(
        trafficMenuTitle(),
        rx.icon(tag="download", size=14),
        width="100%",
        align="center",
        justify="between",
    ),
    rx.divider(height="0.5em", opacity="0"),
    trafficMenuQuantity(),
    rx.divider(height="0.5em", opacity="0"),
    rx.vstack(
        *[
            trafficMenuItem(item["color"], item["title"], item["qty"])
            for item in trafficDataSet.values()
        ],
        width="100%",
    ),
    rx.spacer(),
    rx.button("See More Analytics", width="100%", variant="surface", cursor="pointer"),
    **DashboardTrafficBarStyle.base,
)



import reflex as rx


def background_v4():
    return rx.box(
        rx.box(
            background_size="20px 20px",
            background_image="radial-gradient(circle, hsl(0, 0%, 39%) 1px, transparent 1px), radial-gradient(circle, hsl(0, 0%, 45%) 1px, transparent 1px)",
            mask="linear-gradient(to bottom, hsl(0, 0%, 0%, 0.5), hsl(0, 0%, 0%, 0))",
            width="100%",
            height="65vh",
        ),
        rx.center(
            rx.heading("Buridan UI", size="7", weight="bold", z_index="20"),
            position="absolute",
            top="50%",
            left="50%",
            transform="translate(-50%, -50%)",
        ),
        width="100%",
        height="65vh",
        position="relative",
    )



import reflex as rx

from ..style import Style
from ..wrappers.item import app_profile_item_wrapper

from ..shared.profile_components import (
    profile_item_physical_stats,
    profile_item_unit,
    profile_item_activity_stats,
)

from ..state import State


physical_stats = rx.hstack(
    profile_item_physical_stats(State.height, "height", State.set_height),
    profile_item_physical_stats(State.weight, "weight", State.set_weight),
    profile_item_physical_stats(State.age, "age", State.set_age),
    spacing="6",
    padding="5px 0px",
    display="grid",
    width="100%",
    grid_template_columns=[f"repeat({i}, minmax(0, 1fr))" for i in [1, 1, 1, 3, 3, 3]],
)

L1 = ["sedentary", "active", "moderately active", "very active", "super active"]
L2 = [f"{i + 1} day per week" + ("s" if i > 0 else "") for i in range(7)]
L3 = ["light", "moderate", "intense"]
L4 = [f"{i + 1} hour per night" + ("s" if i > 0 else "") for i in range(9)]

activity_stats = rx.vstack(
    rx.hstack(
        profile_item_activity_stats("Occupation Type", L1),
        profile_item_activity_stats("Exercise Frequency", L2),
        **Style.profile_activity_stat_hstack,
    ),
    rx.hstack(
        profile_item_activity_stats("Exercise Intensity", L3),
        profile_item_activity_stats("Sleep Pattern", L4),
        **Style.profile_activity_stat_hstack,
    ),
    width="100%",
    gap=["12px" if i <= 3 else "32px" for i in range(6)],
)


H1 = ["weight loss", "muscle gain", "maintenance"]
H2 = [f"{i} month" + ("s" if i > 1 else "") for i in [1, 3, 6, 12]]


health_goals = rx.vstack(
    rx.hstack(
        profile_item_activity_stats("Primary Goal", H1),
        profile_item_activity_stats("Timeframe", H2),
        **Style.profile_activity_stat_hstack,
    ),
    width="100%",
    gap=["12px" if i <= 3 else "32px" for i in range(6)],
)

D1 = [
    "vegetarian",
    "vegan",
    "gluten-free",
    "paleo",
    "ketogenic",
    "low-carb",
    "dairy-free",
    "none",
]

D2 = ["nuts", "shellfish", "dairy", "gluten", "soy", "eggs", "wheat", "none"]


diet_restrictions = rx.vstack(
    rx.hstack(
        profile_item_activity_stats("Dietary Restrictions", D1),
        profile_item_activity_stats("Food Allergies", D2),
        **Style.profile_activity_stat_hstack,
    ),
    width="100%",
    gap=["12px" if i <= 3 else "32px" for i in range(6)],
)


def app_profile_panel() -> rx.vstack:
    return rx.vstack(
        rx.divider(height="2em", opacity="0"),
        rx.box(
            rx.vstack(
                app_profile_item_wrapper(
                    "Select the unit of measurements for your data.",
                    "Unit Measurement",
                    [profile_item_unit()],
                ),
                app_profile_item_wrapper(
                    "Enter details about your physical characteristics.",
                    "Physical Stats",
                    [physical_stats],
                ),
                app_profile_item_wrapper(
                    "Help us understand your daily lifestyle and activity level.",
                    "Lifestyle & Activity Level",
                    [activity_stats],
                ),
                app_profile_item_wrapper(
                    "Tell us about your health and fitness goals.",
                    "Health Goals",
                    [health_goals],
                ),
                app_profile_item_wrapper(
                    "Let us know your dietary preferences and restrictions.",
                    "Dietary Preferences",
                    [diet_restrictions],
                ),
                **Style.profile_inner_content,
            ),
            padding=["0em 4em" if i >= 5 else "0em 2em" for i in range(6)],
            width="100%",
        ),
        **Style.profile_base,
    )



import reflex as rx


def prompt_v2():
    return rx.center(
        rx.vstack(
            rx.text_area(
                placeholder="Ask me anything...",
                width="100%",
                height="100%",
                rows="4",
                padding_bottom="35px",
            ),
            rx.hstack(
                rx.button(
                    "Send",
                    height="20px",
                    padding="5px",
                    variant="surface",
                ),
                width="100%",
                align="center",
                justify="end",
                position="absolute",
                bottom="0",
                left="0",
                padding="10px 12px",
            ),
            position="relative",
            width="100%",
            max_width="40em",
            border=f"1px solid {rx.color('gray', 6)}",
            border_radius="8px",
        ),
        width="100%",
        height="25vh",
    )



import reflex as rx
from dataclasses import dataclass, field
from typing import Callable


@dataclass
class InputsV1Style:
    root: dict[str, str] = field(
        default_factory=lambda: {"width": "100%", "height": "100%", "align": "center"}
    )

    base: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "max_width": "30em",
            "border_radius": "5px",
            "padding": "2.5px 10px",
            "spacing": "0",
            "transition": "all 350ms ease",
        }
    )

    text: dict[str, str] = field(
        default_factory=lambda: {
            "size": "1",
            "weight": "bold",
            "padding": "8px 8px 0px 8px",
            "color": rx.color("slate", 11),
        }
    )

    entry: dict[str, str] = field(
        default_factory=lambda: {
            "outline": "none",
            "variant": "soft",
            "width": "100%",
            "background": "transparent",
        }
    )

    active_border: dict[str, str] = field(
        default_factory=lambda: {
            "border": f"2px solid {rx.color('blue', 7)}",
        }
    )

    passive_border: dict[str, str] = field(
        default_factory=lambda: {
            "border": f"2px solid {rx.color('gray', 5)}",
        }
    )


InputsV1Style: InputsV1Style = InputsV1Style()

data: list[list[str]] = [
    ["Shipping Address", "1234 Street, New York City"],
    ["Card Number", "1234 5678 1243 4332"],
]


class InputV1State(rx.State):

    data: list[list[str]] = [
        [*item, InputsV1Style.passive_border["border"]] for item in data
    ]

    def on_entry_select(self, strings: list[str]):
        self.data = [
            (
                [*strings[:2], InputsV1Style.active_border["border"]]
                if strings[0] == item[0]
                else [*item[:2], InputsV1Style.passive_border["border"]]
            )
            for item in self.get_value(self.data)
        ]

    def on_entry_blur(self, e=None):
        self.data = [
            [*item[:2], InputsV1Style.passive_border["border"]] for item in data
        ]


title: Callable[[str], rx.Component] = lambda txt: rx.text(txt, **InputsV1Style.text)

entry: Callable[[str, list[str]], rx.Component] = lambda placeholder, strings: rx.input(
    placeholder=placeholder,
    on_focus=InputV1State.on_entry_select(strings),
    on_blur=InputV1State.on_entry_blur,
    **InputsV1Style.entry,
)

stack: Callable[[list[str]], rx.Component] = lambda strings: rx.vstack(
    title(strings[0]),
    entry(strings[1], strings),
    border=strings[2],
    **InputsV1Style.base,
)


def inputs_v1():
    return rx.vstack(rx.foreach(InputV1State.data, stack), **InputsV1Style.root)



import reflex as rx

from ..style import tooltip_styles, info
from ...wrappers.state import ComponentWrapperState


def linechart_v5():

    data = [
        {"browser": "chrome", "visitors": 275},
        {"browser": "safari", "visitors": 200},
        {"browser": "firefox", "visitors": 187},
        {"browser": "edge", "visitors": 173},
        {"browser": "other", "visitors": 90},
    ]

    return rx.center(
        rx.vstack(
            info(
                "Line Chart - Title Label",
                "3",
                "Showing total visitors for the last 6 months",
                "start",
            ),
            rx.recharts.line_chart(
                rx.recharts.graphing_tooltip(**vars(tooltip_styles)),
                rx.recharts.cartesian_grid(
                    horizontal=True,
                    vertical=False,
                    fill_opacity=0.5,
                    stroke=rx.color("slate", 5),
                ),
                rx.recharts.line(
                    rx.recharts.label_list(
                        position="top",
                        offset=20,
                        custom_attrs={"fontSize": "12px", "fontWeight": "bold"},
                        data_key="browser",
                    ),
                    data_key="visitors",
                    stroke=ComponentWrapperState.default_theme[1],
                    type_="natural",
                    dot=True,
                ),
                data=data,
                width="100%",
                height=250,
                margin={"left": 25, "right": 20, "top": 25},
            ),
            info("Trending up by 5.2% this month", "2", "January - June 2024", "start"),
            width="100%",
            margin_right="20px",
        ),
        width="100%",
        padding="0.5em",
    )



import reflex as rx


class Table(rx.State):
    data: list[dict[str, str]] = [
        {
            "avatar": "https://raw.githubusercontent.com/mantinedev/mantine/master/.demo/avatars/avatar-1.png",
            "name": "Robert Wolfkisser",
            "job": "Engineer",
            "email": "rob_wolf@gmail.com",
            "phone": "+44 (452) 886 09 12",
        },
        {
            "avatar": "https://raw.githubusercontent.com/mantinedev/mantine/master/.demo/avatars/avatar-7.png",
            "name": "Jill Jailbreaker",
            "job": "Engineer",
            "email": "jj@breaker.com",
            "phone": "+44 (934) 777 12 76",
        },
        {
            "avatar": "https://raw.githubusercontent.com/mantinedev/mantine/master/.demo/avatars/avatar-2.png",
            "name": "Henry Silkeater",
            "job": "Designer",
            "email": "henry@silkeater.io",
            "phone": "+44 (901) 384 88 34",
        },
        {
            "avatar": "https://raw.githubusercontent.com/mantinedev/mantine/master/.demo/avatars/avatar-3.png",
            "name": "Bill Horsefighter",
            "job": "Designer",
            "email": "bhorsefighter@gmail.com",
            "phone": "+44 (667) 341 45 22",
        },
        {
            "avatar": "https://raw.githubusercontent.com/mantinedev/mantine/master/.demo/avatars/avatar-10.png",
            "name": "Jeremy Footviewer",
            "job": "Manager",
            "email": "jeremy@foot.dev",
            "phone": "+44 (881) 245 65 65",
        },
    ]

    color_map: dict[str, str] = {
        "Engineer": "blue",
        "Manager": "cyan",
        "Designer": "pink",
    }


def create_data_row(data: dict[str, str]):
    return rx.table.row(
        rx.table.cell(
            rx.hstack(
                rx.avatar(src=data["avatar"], size="1"),
                rx.text(
                    data["name"], color_scheme="gray", font_size="11px", weight="medium"
                ),
                align="center",
            ),
        ),
        rx.table.cell(
            rx.badge(data["job"], color_scheme=Table.color_map[data["job"]], size="1"),
        ),
        rx.table.cell(
            rx.text(
                data["email"],
                color_scheme="blue",
                font_size="11px",
                _hover={"text_decoration_line": "underline"},
                cursor="pointer",
            )
        ),
        rx.table.cell(
            rx.text(
                data["phone"], color_scheme="gray", font_size="11px", weight="regular"
            ),
        ),
        rx.table.cell(rx.icon(tag="pencil", size=13, color="gray")),
        rx.table.cell(rx.icon(tag="trash-2", size=13)),
        align="center",
        white_space="nowrap",
    )


def tables_v2():
    return rx.table.root(
        rx.table.header(
            rx.table.row(
                rx.foreach(
                    ["Employee", "Job Title", "Email", "Phone", "", ""],
                    lambda title: rx.table.column_header_cell(
                        rx.text(title, font_size="12px", weight="bold")
                    ),
                )
            ),
        ),
        rx.table.body(
            rx.foreach(Table.data, create_data_row),
        ),
        width="100%",
        variant="surface",
        max_width="800px",
        size="2",
    )



from dataclasses import dataclass, field
from typing import Callable, Dict, List
import reflex as rx


padding: Callable[[], list[str]] = lambda: [
    "12px 0px" if i >= 5 else "12px 12px" for i in range(6)
]

WrapperShared: Dict[str, str | List[str]] = {
    "width": "100%",
    "spacing": "5",
    "padding": padding(),
}
TitlesShared: Dict[str, str] = {"width": "100%", "spacing": "4"}


@dataclass
class LandingPageSectionWrapperStyle:
    wrapper: dict[str, str] = field(
        default_factory=lambda: {"align": "start", **WrapperShared}
    )

    wrapper_secondary: dict[str, str] = field(
        default_factory=lambda: {"align": "start", **WrapperShared}
    )

    titles: dict[str, str] = field(
        default_factory=lambda: {
            "align": "start",
            "text_align": "start",
            "max_width": "48em",
            **TitlesShared,
        }
    )

    titles_secondary: dict[str, str] = field(
        default_factory=lambda: {
            "align": "start",
            "text_align": "start",
            "max_width": "38em",
            **TitlesShared,
        }
    )

    blip: dict[str, str] = field(
        default_factory=lambda: {
            "width": "24px",
            "height": "24px",
            "border_radius": "24px",
            "background": rx.color("blue", 3),
            "border": f"1.25px solid {rx.color('blue', 6)}",
            "position": "absolute",
            "left": "-11.5px",
            "align_items": "center",
            "justify_content": "center",
            "display": "flex",
        }
    )

    features: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "align": "start",
            "justify": "start",
            "padding_left": "24px",
            "border_radius": "0px 5px 5px 0px",
            "position": "relative",
            "border_left": f"1px solid {rx.color('blue', 6)}",
        }
    )


@dataclass
class LandingPageButtons:
    base: dict[str, str] = field(
        default_factory=lambda: {"radius": "small", "cursor": "pointer"}
    )


LandingPageButtons: LandingPageButtons = LandingPageButtons()

LandingPageSectionWrapperStyle: LandingPageSectionWrapperStyle = (
    LandingPageSectionWrapperStyle()
)



import reflex as rx

from ....charts.line.v1 import linechart_v1
from ....charts.area.v4 import areachart_v4
from ....charts.bar.v1 import barchart_v1
from ....charts.pie.v2 import piechart_v2


line = linechart_v1()
area = areachart_v4()
bar = barchart_v1()
pie = piechart_v2()


def landing_page_chart_items() -> rx.tabs:
    return rx.tabs.root(
        rx.tabs.list(
            *[
                rx.tabs.trigger(name, value=str(i + 1), flex="1", cursor="pointer")
                for i, name in enumerate(
                    ["Line Chart", "Area Chart", "Bar Chart", "Pie Chart"]
                )
            ],
        ),
        *[
            rx.tabs.content(
                fn,
                value=str(i + 1),
                width="100%",
                padding="2em 0em",
            )
            for i, fn in enumerate([line, area, bar, pie])
        ],
        default_value="1",
        width="100%",
    )



from dataclasses import dataclass, field
import reflex as rx


@dataclass
class LandingPageStyle:
    base: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "min_height": "100vh",
            "align": "center",
            "spacing": "0",
            "background": rx.color("slate", 2),
        }
    )

    content: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "height": "100%",
            "max_width": "75em",
            "position": "relative",
            "padding": ["0em 0.5em" if i <= 5 else "0em 0em" for i in range(6)],
        }
    )


LandingPageStyle: LandingPageStyle = LandingPageStyle()



import reflex as rx

from typing import Callable

from .style import LayoutStyleSheet

from .components.navigation import layoutNavigation
from .components.blocks import blockTypeOne


layoutDoubleColumn: Callable[[], rx.Component] = lambda: rx.hstack(
    rx.vstack(**LayoutStyleSheet.doubleColumnLeft),
    rx.vstack(
        layoutNavigation(), blockTypeOne(), **LayoutStyleSheet.doubleColumnContentArea
    ),
    **LayoutStyleSheet.doubleColumn,
)

layoutSingleColumn: Callable[[], rx.Component] = lambda: rx.vstack(
    layoutNavigation(),
    rx.divider(height="5em", opacity="0"),
    blockTypeOne(),
    **LayoutStyleSheet.singleColumn,
)



import reflex as rx

from dataclasses import dataclass, field


@dataclass
class BackgroundStyle:
    grid: dict[str, str] = field(
        default_factory=lambda: {
            "background_size": "30px 30px",
            "background_image": f"radial-gradient(circle, {rx.color('slate', 12)} 0.75px, transparent 1px)",
            "mask": (
                "radial-gradient(45% 45% at 50% 50%, hsl(0, 0%, 0%, 0.60), hsl(0, 0%, 0%, 0)), "
                "radial-gradient(60% 70% at 50% 50%, hsl(0, 0%, 0%, 0.35), hsl(0, 0%, 0%, 0))"
            ),
            "width": "100%",
            "height": "100vh",
            "position": "absolute",
            "top": "0",
            "left": "0",
            "z_index": "-2",
        }
    )

    landing: dict[str, str] = field(
        default_factory=lambda: {
            "background_size": "30px 30px",
            "background_image": f"radial-gradient(circle, {rx.color('slate', 12)} 1px, transparent 1px)",
            "mask": (
                "radial-gradient(45% 45% at 50% 50%, hsl(0, 0%, 0%, 0.60), hsl(0, 0%, 0%, 0)), "
                "radial-gradient(60% 70% at 50% 50%, hsl(0, 0%, 0%, 0.35), hsl(0, 0%, 0%, 0))"
            ),
            "width": "100%",
            "height": "110vh",
            "position": "absolute",
            "top": "0",
            "left": "0",
        }
    )


BackgroundStyle: BackgroundStyle = BackgroundStyle()


def grid_background():
    return rx.box(**BackgroundStyle.grid)


def landing_page_grid_background():
    return rx.box(**BackgroundStyle.landing)



import reflex as rx

services = [
    ["Website Design", "Content Creation"],
    ["UX Design", "Consulting"],
    ["Research", "Other"],
]


def item_and_title(title: str, placeholder: str):
    return rx.vstack(
        rx.text(title, font_size="11px", weight="medium", color_scheme="gray"),
        rx.input(placeholder=placeholder, width="100%"),
        width="100%",
        spacing="2",
    )


def check_box_item(name: str):
    return rx.box(rx.checkbox(name), width="100%")


def forms_v1():

    return rx.vstack(
        rx.vstack(
            rx.heading("Contact our team", size="5", weight="bold"),
            rx.text(
                "Got any questions about the product? We're here to help. Fill out the form below to get started.",
                font_size="12px",
                weight="medium",
                color_scheme="gray",
                text_align="center",
            ),
            width="100%",
            spacing="1",
            align="center",
            padding="12px 0px",
        ),
        rx.hstack(
            item_and_title("First Name", "First name"),
            item_and_title("Last Name", "Last name"),
            width="100%",
            display="flex",
        ),
        item_and_title("Email", "example@someplace.com"),
        rx.vstack(
            rx.text("Message", font_size="11px", color_scheme="gray", weight="medium"),
            rx.text_area(
                width="100%",
                placeholder="Leave us message...",
                rows="5",
            ),
            width="100%",
            spacing="2",
        ),
        rx.vstack(
            rx.text("Services", font_size="11px", color_scheme="gray", weight="medium"),
            *[
                rx.hstack(
                    check_box_item(x),
                    check_box_item(y),
                    width="100%",
                )
                for x, y in services
            ],
            width="100%",
            spacing="2",
        ),
        rx.spacer(),
        rx.button(
            "Continue",
            width="100%",
            cursor="pointer",
            variant="surface",
            color_scheme="gray",
        ),
        width="100%",
        max_width="21em",
        height="100%",
        justify="center",
        align="center",
    )



from dataclasses import dataclass, field
from typing import Dict

import reflex as rx


@dataclass
class DashboardNavBarStyle:
    base: Dict[str, str] = field(
        default_factory=lambda: {
            "top": "0",
            "left": "0",
            "width": "100%",
            "spacing": "4",
            "z_index": "2",
            "justify": "end",
            "align": "center",
            "position": "sticky",
            "padding": "0.75em 2em",
            "background": rx.color("gray", 2),
            "border_bottom": f"1px solid {rx.color('gray', 4)}",
        }
    )


DashboardNavBarStyle: DashboardNavBarStyle = DashboardNavBarStyle()



from .buridan import buridan
from .installation import installation
from .introduction import introduction
from ..changelog.changelog import changelog


getting_started_config = {
    "buridan": [buridan],
    "installation": [installation],
    "introduction": [introduction],
    "changelog": [changelog],
}



import reflex as rx

from typing import Callable, List
from functools import wraps

from reflex.components.datadisplay.code import Theme

from buridan_ui.wrappers.state import ComponentWrapperState
from .style import ComponentWrapperStyle, InnerCode

from buridan_ui.wrappers.shared.tabs import component_wrapper_tab_menu
from buridan_ui.wrappers.shared.responsive import component_wrapper_responsive_menu
from buridan_ui.wrappers.shared.source import component_wrapper_source_code
from buridan_ui.wrappers.shared.scheme import component_wrapper_color_scheme


def component_wrapper_menu_bar(has_theme: bool, component_id: int, path: str):
    return rx.hstack(
        rx.hstack(
            (component_wrapper_color_scheme() if has_theme else rx.spacer()),
            (
                rx.divider(
                    width="0.75px",
                    height="25px",
                    orientation="vertical",
                    display=["none" if i <= 1 else "flex" for i in range(6)],
                )
                if has_theme
                else rx.spacer()
            ),
            component_wrapper_responsive_menu(component_id),
            rx.divider(
                width="0.75px",
                height="25px",
                orientation="vertical",
                display=["none" if i <= 3 else "flex" for i in range(6)],
            ),
            component_wrapper_source_code(path),
            align="center",
        ),
        align="center",
        justify="end",
        width="100%",
    )


def component_wrapper_menu_bar_no_code(path: str):
    return rx.hstack(
        rx.badge("Responsive UI", size="1", variant="surface"),
        component_wrapper_source_code(path),
        align="center",
        justify="end",
        width="100%",
    )


def component_wrapper_preview_content(component: rx.Component, component_id: int):
    return rx.tabs.content(
        rx.vstack(
            component,
            width=[
                ("100%" if i <= 3 else ComponentWrapperState.uuid[component_id])
                for i in range(6)
            ],
            **ComponentWrapperStyle.preview,
        ),
        value="1",
    )


def component_wrapper_code_base(
    component_code: str,
    value: str = "2",
) -> rx.tabs.content:
    return rx.tabs.content(
        rx.hstack(
            rx.code_block(
                component_code,
                theme=Theme.darcula,
                **ComponentWrapperStyle.code,
            ),
            rx.button(
                rx.cond(
                    ComponentWrapperState.default_icon,
                    rx.icon(tag="clipboard-list", size=14),
                    rx.icon(tag="check", size=14, color=rx.color("grass")),
                ),
                on_click=[
                    ComponentWrapperState.toggle_icon,
                    rx.set_clipboard(component_code),
                ],
                **ComponentWrapperStyle.copy_button,
            ),
            **InnerCode,
        ),
        value=value,
    )


def component_wrapper(path: str, has_theme: bool = False):
    def decorator(func: Callable[[], List[rx.Component | str | int]]):
        @wraps(func)
        def wrapper():
            component, component_code, component_id = func()

            return rx.vstack(
                component_wrapper_menu_bar(has_theme, component_id, path),
                rx.tabs.root(
                    component_wrapper_tab_menu(),
                    component_wrapper_preview_content(component, component_id),
                    component_wrapper_code_base(component_code),
                    **ComponentWrapperStyle.root,
                ),
                width="100%",
            )

        return wrapper

    return decorator



from collections.abc import Callable

import reflex as rx

from dataclasses import dataclass, field
from reflex.constants.colors import Color

from buridan_ui.pantry.footers.v1 import FooterV1Style

active: Color = rx.color("slate", 12)
passive: Color = rx.color("slate", 10)


@dataclass
class FooterV2Style:
    base: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "height": "20vh",
            "align": "center",
            "justify": "center",
            "padding": "0em 1em",
        }
    )

    content: dict[str, str] = field(
        default_factory=lambda: {
            "width": "100%",
            "max_width": "35em",
            "justify": "between",
            "align": "center",
            "padding": "1em 0em",
        }
    )

    link: dict[str, str] = field(
        default_factory=lambda: {"color": passive, "size": "2"}
    )

    brand: dict[str, str] = field(
        default_factory=lambda: {"color": active, "size": "2"}
    )


FooterV2Style: FooterV2Style = FooterV2Style()

media: Callable[[str], rx.Component] = lambda name: rx.link(
    rx.text(name, **FooterV1Style.link), href="#"
)


def footer_v2() -> rx.vstack:
    return rx.vstack(
        rx.divider(max_width="35em", color=rx.color("slate", 11)),
        rx.hstack(
            rx.text("© 2024 Buridan UI", **FooterV2Style.brand),
            rx.hstack(media("Twitter"), media("Dribble"), media("GitHub")),
            **FooterV2Style.content,
        ),
        **FooterV2Style.base,
    )



from typing import Callable
import asyncio
import reflex as rx
from dataclasses import dataclass, field


@dataclass
class AnimationStyle:

    dash: dict[str, str] = field(
        default_factory=lambda: {
            "position": "absolute",
            "width": "2px",
            "height": "100%",
            "top": "20px",
            "background": rx.color("gray", 5),
            "overflow": "hidden",
            "border_radius": "50%",
            "::after": {
                "content": "''",
                "display": "block",
                "position": "absolute",
                "height": "10vh",
                "width": "100%",
                "top": "-50%",
                "left": 0,
                "border": f"2px dashed {rx.color('red')}",
                "animation": "drop 1.5s 0s infinite",
                "animation-fill-mode": "forwards",
            },
        },
    )

    button: dict[str, str] = field(
        default_factory=lambda: {
            "top": "-24px",
            "right": "-12px",
            "cursor": "pointer",
            "position": "absolute",
            "border_radius": "0px 0px 0px 8px",
        }
    )

    dash_animation: dict[str, str] = field(
        default_factory=lambda: {
            "@keyframes drop": {"0%": {"top": "-50%"}, "100%": {"top": "100%"}}
        }
    )

    text: dict[str, str] = field(
        default_factory=lambda: {"size": "1", "weight": "bold"}
    )


AnimationStyle: AnimationStyle = AnimationStyle()

active_blip = {"opacity": "1"}
passive_blip = {"opacity": "0.71"}

active_text = {"filter": "blur(0px)", "transform": "scale(1)", "opacity": "1"}
passive_text = {"filter": "blur(10px)", "transform": "scale(1.15)", "opacity": "0"}


class AnimationState(rx.State):
    is_disabled: bool = False

    blip: dict[str, str] = passive_blip
    blip_color: str = "gray"
    blip_type: str = "surface"

    text: dict[str, str] = passive_text

    runner: dict[str, str] = {}

    async def run_animation(self):
        self.is_disabled = True
        yield

        self.blip, self.text, self.blip_color, self.blip_type = (
            active_blip,
            active_text,
            "red",
            "solid",
        )
        self.runner = AnimationStyle.dash_animation
        yield
        await asyncio.sleep(5)
        await self.stop_animation()
        self.is_disabled = False

    async def stop_animation(self):
        self.reset()
        self.runner = {}


dash = rx.box(**AnimationStyle.dash, style=AnimationState.runner)


def blip(delay: int):

    return rx.badge(
        "-",
        width="21px",
        height="21px",
        position="absolute",
        border_radius="21px",
        left="-9.5px",
        display="flex",
        align_items="center",
        justify_content="center",
        transition=f"all 300ms ease {delay}ms",
        variant=AnimationState.blip_type,
        color_scheme=AnimationState.blip_color,
        style=AnimationState.blip,
    )


wrapper: Callable[[str, str, str, int], rx.box] = (
    lambda issue, response, posY, delay: rx.box(
        rx.hstack(
            rx.vstack(
                rx.vstack(
                    rx.hstack(
                        blip(delay),
                        rx.text(
                            issue,
                            color=rx.color("slate", 12),
                            style=AnimationState.text,
                            transition=f"all 300ms ease {delay}ms",
                            **AnimationStyle.text,
                        ),
                        align="center",
                    ),
                    spacing="1",
                    wrap="wrap",
                ),
                rx.text(
                    response,
                    color=rx.color("slate", 11),
                    style=AnimationState.text,
                    transition=f"all 300ms ease {delay}ms",
                    **AnimationStyle.text,
                ),
                rx.divider(height="2em", opacity="0"),
            ),
            width="100%",
            align="start",
            justify="start",
            padding_left="2em",
            top=posY,
        ),
        position="relative",
    )
)


def animation_v6():
    return rx.vstack(
        rx.vstack(
            dash,
            wrapper(
                "Build and Test",
                "Runs tests after building the project to ensure code quality.",
                "20%",
                350,
            ),
            wrapper(
                "Deploy to Staging",
                "Deploys the application to the staging environment for QA.",
                "40%",
                550,
            ),
            wrapper(
                "Release Production",
                "Builds and deploys the latest version to production.",
                "60%",
                750,
            ),
            wrapper(
                "Run Unit Tests",
                "Executes unit tests for individual components of the project.",
                "80%",
                950,
            ),
            max_width="40em",
            padding="1em 0em",
        ),
        rx.button(
            "Run",
            loading=AnimationState.is_disabled,
            on_click=AnimationState.run_animation,
            **AnimationStyle.button,
        ),
        position="relative",
        width="100%",
        height="50vh",
        align="center",
        justify="center",
        padding="1em",
    )



import reflex as rx
from ..style import tooltip_styles, info
from ...wrappers.component.wrapper import ComponentWrapperState


def radar_v5():

    stats = [
        {"category": "Farming", "score": 8},
        {"category": "Fighting", "score": 7},
        {"category": "Aggressiveness", "score": 6},
        {"category": "Map Awareness", "score": 5},
        {"category": "Objective Control", "score": 9},
        {"category": "Positioning", "score": 7},
    ]

    return rx.vstack(
        info(
            "Radar Chart - Circle Grid",
            "3",
            "Player performance across key gameplay categories",
            "center",
        ),
        rx.recharts.radar_chart(
            rx.recharts.graphing_tooltip(**vars(tooltip_styles)),
            rx.recharts.polar_grid(
                class_name=rx.color_mode_cond(
                    "text-sm stroke-gray-300", "text-sm stroke-gray-700"
                ),
                grid_type="circle",
            ),
            rx.recharts.polar_angle_axis(
                data_key="category",
                class_name=rx.color_mode_cond(
                    "text-sm stroke-gray-300", "text-sm stroke-gray-700"
                ),
                axis_line_type="circle",
            ),
            rx.recharts.radar(
                data_key="score",
                dot=True,
                stroke=ComponentWrapperState.default_theme[0],
                custom_attrs={
                    "fill": ComponentWrapperState.default_theme[1],
                    "strokeWidth": 2,
                },
            ),
            data=stats,
            width="100%",
            height=250,
            margin={"left": 20, "right": 20},
        ),
        info(
            "Trending up by 5.2% this month",
            "2",
            "Performance trends in key gameplay categories",
            "center",
        ),
        width="100%",
        align="center",
        padding="0.5em",
    )



import reflex as rx

from ..style import tooltip_styles, info
from ...wrappers.state import ComponentWrapperState


def areachart_v3():

    data = [
        {"month": "Jan", "desktop": 186},
        {"month": "Feb", "desktop": 305},
        {"month": "Mar", "desktop": 237},
        {"month": "Apr", "desktop": 73},
        {"month": "May", "desktop": 209},
        {"month": "Jun", "desktop": 214},
    ]

    return rx.center(
        rx.vstack(
            info(
                "Area Chart - Step",
                "3",
                "Showing total visitors for the last 6 months",
                "start",
            ),
            rx.recharts.area_chart(
                rx.recharts.graphing_tooltip(**vars(tooltip_styles)),
                rx.recharts.cartesian_grid(
                    horizontal=True,
                    vertical=False,
                    fill_opacity=0.5,
                    stroke=rx.color("slate", 5),
                ),
                rx.recharts.area(
                    data_key="desktop",
                    fill=ComponentWrapperState.default_theme[1],
                    stroke=ComponentWrapperState.default_theme[2],
                    type_="step",
                ),
                rx.recharts.x_axis(
                    data_key="month",
                    axis_line=False,
                    tick_size=10,
                    tick_line=False,
                    custom_attrs={"fontSize": "12px"},
                ),
                data=data,
                width="100%",
                height=250,
                margin={"left": 20},
            ),
            info(
                "Trending up by 5.2% this month",
                "2",
                "January - June 2024",
                "start",
            ),
            width="100%",
            margin_right="20px",
        ),
        width="100%",
        padding="0.5em",
    )



import reflex as rx
from functools import wraps
from typing import Callable, List

from .style import BlueprintWrapperStyle

from ..shared.source import component_wrapper_source_code

blueprintAppWrapperMenu: Callable[[str], rx.Component] = lambda path: rx.hstack(
    rx.badge("Responsive UI", size="1", variant="surface"),
    component_wrapper_source_code(path),
    align="center",
    justify="end",
    width="100%",
)

blueprintAppPreview: Callable[[rx.Component], rx.Component] = (
    lambda component: rx.tabs.content(
        rx.vstack(component, **BlueprintWrapperStyle.preview),
        value="1",
    )
)


blueprintAppCode: Callable[[dict], rx.Component] = lambda struct: rx.tabs.content(
    value="2",
)


def blueprint_app_wrapper(url: str):
    def decorator(func: Callable[[], list[rx.Component | str | int]]):
        @wraps(func)
        def wrapper():
            component = func()
            if not isinstance(component, List):
                raise TypeError("The wrapped blueprint item is not a list.")

            return rx.vstack(
                blueprintAppWrapperMenu(url),
                rx.tabs.root(
                    blueprintAppPreview(component[0]),
                    **BlueprintWrapperStyle.root,
                ),
                width="100%",
            )

        return wrapper

    return decorator



from typing import List, AsyncGenerator
from random import randint

from .style import AuthDynamicStyle

import asyncio
import reflex as rx


numberList: List[str] = [
    "one",
    "two",
    "three",
    "four",
    "five",
    "six",
    "seven",
    "eight",
    "nine",
    "ten",
    "eleven",
    "twelve",
    "thirteen",
    "fourteen",
    "fifteen",
    "sixteen",
]


class SandboxAuthState(rx.State):
    # ... account numbers vars ...
    one: str = "_"
    two: str = "_"
    three: str = "_"
    four: str = "_"

    five: str = "_"
    six: str = "_"
    seven: str = "_"
    eight: str = "_"

    nine: str = "_"
    ten: str = "_"
    eleven: str = "_"
    twelve: str = "_"

    thirteen: str = "_"
    fourteen: str = "_"
    fifteen: str = "_"
    sixteen: str = "_"

    # ... generate button vars ...
    authGenButton: dict[str, bool] = AuthDynamicStyle.passive

    # ... alert text vars ...
    authAlert: dict[str, str] = AuthDynamicStyle.alert_passive

    # ... dummy vars
    accountNumber: str

    @rx.event
    async def can_copy_account_number(self) -> rx.event:
        if self.accountNumber:
            yield rx.set_clipboard(self.accountNumber)
            yield rx.toast.info("Copied account number.")

        else:
            yield rx.toast.warning("No account number generated yet.")

    async def run_number_animation(self, place_name: str):
        for _ in range(35):
            number = str(randint(0, 9))
            setattr(self, place_name, number)
            yield
            await asyncio.sleep(0.061)

    @rx.event
    async def run_animation_task(self) -> AsyncGenerator:
        self.authGenButton = AuthDynamicStyle.active
        yield
        tasks = [self.run_number_animation(number) for number in numberList]

        for _ in range(35):
            await asyncio.gather(*[task.__anext__() for task in tasks])
            yield

        for number_name in numberList:
            value = getattr(self, number_name)
            self.accountNumber += value

        yield
        self.authGenButton = AuthDynamicStyle.finished
        self.authAlert = AuthDynamicStyle.alert_active



callback = """
function getEditorContent() {
    var editor = ace.edit("editor");
    var code = editor.getValue();  // Get the content of the editor

    // Optionally, you could update the content somewhere
    // document.getElementById("codeOutput").textContent = code;
}

function setupEditor() {
    var editor = ace.edit("editor");

    // Enable language tools and features
    ace.config.loadModule('ace/ext/language_tools', function() {
        var langTools = ace.require('ace/ext/language_tools');  // Only require langTools once

        // Set editor options for autocompletion
        editor.setOptions({
            enableBasicAutocompletion: true,
            enableLiveAutocompletion: true,
            enableSnippets: true,
            wrap: true,
            useWrapMode: true,
            showPrintMargin: false,
            tabSize: 4,           // Set the number of spaces for each tab
            useSoftTabs: true,    // Use spaces instead of tabs
            indentedSoftWrap: true // Indent wrapped lines
        });

        // Set the mode to Python for syntax highlighting
        editor.session.setMode("ace/mode/python");
        editor.renderer.setShowGutter(true);
        editor.renderer.setPadding(10);
        editor.$blockScrolling = Infinity;

        // Update the code block on editor change (optional)
        editor.session.on('change', function() {
            getEditorContent();  // Update content whenever editor changes
        });
    });
}

setupEditor();  // Initialize the editor and set it up

"""


dynamics = """
function getEditorContentAutomatic() {
   var editor = ace.edit("editor");
   var code = editor.getValue();
   return code;
}
getEditorContentAutomatic();  // Call the function to get the content
"""



import reflex as rx

PASSIVE: dict = {"top": "-20px", "left": "-20px", "opacity": "0"}
ACTIVE: dict = {"top": "-20px", "left": "0px", "opacity": "1"}


class Animation(rx.State):
    value: str
    position: dict = PASSIVE

    async def run_animation(self, new_value: str):
        self.value = new_value

        if len(self.value) >= 1:
            self.position = ACTIVE
            yield

        if len(self.value) == 0:
            self.position = PASSIVE
            yield


def animation_v3():
    return rx.center(
        rx.hstack(
            rx.input(
                value=Animation.value,
                placeholder="Email Address",
                variant="surface",
                color_scheme="gray",
                width="100%",
                on_change=Animation.run_animation,
            ),
            rx.text(
                "Email Address",
                size="1",
                color=rx.color("slate", 11),
                position="absolute",
                transition="all 150ms ease",
                style=Animation.position,
            ),
            position="relative",
            max_width="15em",
            width="100%",
        ),
        width="100%",
        height="20em",
    )



import reflex as rx

from ..style import tooltip_styles, info
from ...wrappers.state import ComponentWrapperState

from typing import Any

def barchart_v1(
    data: rx.Var[list[dict[str, Any]]],
    x: rx.Var[str],
    y: rx.Var[str] | rx.Var[list[str]] | None = None,
    x_label: rx.Var[str] | None = None,
    # y_label: rx.Var[str] | None = None,
    # color: rx.Var[str] | None = None,
    # horizontal: rx.Var[bool] = False,
    # height: rx.Var[int] = rx.Var.create(250),
):
    """Graph data in a bar chart.

    Example usage:
    class State(rx.State):
        # INCLUDE FULL TYPE ANNOTATION!
        data: list[dict[str, Any]] = [
            {"name": "John", "age": 30, "city": "New York"},
        ]
    ...

    # Always prefer to hook up to state!
    barchart_v1(data=State.data, x="name", y=["age"], x_label="Name")
    """

    return rx.center(
        rx.vstack(
            rx.recharts.bar_chart(
                rx.recharts.graphing_tooltip(**vars(tooltip_styles)),
                rx.recharts.cartesian_grid(horizontal=True, vertical=False),
                rx.foreach(
                    y,
                    lambda name, index: rx.recharts.bar(
                        data_key=name,
                        fill=ComponentWrapperState.default_theme[index],
                        radius=6,
                    ),
                ),
                rx.recharts.x_axis(
                    data_key=x,
                    axis_line=False,
                    tick_size=10,
                    tick_line=False,
                    label=x_label,
                ),
                data=data,
                width="100%",
                height=250,
                bar_size=50,
                bar_gap=2,
                bar_category_gap="0%",
            ),
            width="100%",
        ),
        width="100%",
        padding="0.5em",
    )



import reflex as rx

from ..templates.navigation.navigation import landing_page_navigation
from ..pages.landing.style import LandingPageStyle

from .components.editor import ace_editor
from .scripts import callback, dynamics
from .state import Editor


from ..pantry.logins.v1 import LoginStyle


@rx.dynamic
def rendered_component(state: Editor):
    # Create a dictionary to capture the context (globals) where the code is executed
    context = {
        "rx": rx,
        "LoginStyle": LoginStyle,
    }

    try:
        # Execute the code in the given context
        exec(state.code, context)

        # Check for a defined component in the context, either directly or from a function call
        component = None

        # Look for any variable in the context that is a valid component
        for name, value in context.items():
            if isinstance(value, rx.Component):
                component = value
                break

        # If no component found, check if there's any function to call (e.g., first function in context)
        if component is None:
            for name, value in context.items():
                if callable(value):  # If it's callable (a function)
                    component = value()  # Call the function and return its result
                    break

    except Exception as e:
        # If there's an error executing the code, return an error message
        return rx.text(f"Error: {e}")

    # Check if 'component' is a valid rx.Component
    if not isinstance(component, rx.Component):
        return rx.text("Invalid component")

    return component


def buridan_sandbox():
    return rx.vstack(
        rx.script(callback),
        rx.script(dynamics),
        rx.vstack(
            landing_page_navigation(),
            rx.hstack(
                rx.select(
                    ["Login V1", "Login V2"],
                    placeholder="Select Component",
                    on_change=Editor.handle_selection,
                    size="1",
                ),
                width="100%",
                justify="end",
            ),
            rx.hstack(
                ace_editor(),
                rx.vstack(
                    rendered_component(),
                    height="100%",
                    align="center",
                    justify="center",
                    flex=["100%" if i <= 3 else "30%" for i in range(6)],
                ),
                width="100%",
                height="100%",
                wrap="wrap",
                align="center",
            ),
            **LandingPageStyle.content,
        ),
        **LandingPageStyle.base,
    )



import reflex as rx


def subscribe_v2():

    return rx.center(
        rx.vstack(
            rx.text(
                "Sign up to our newsletter",
                size="4",
                weight="bold",
                color=rx.color("slate", 12),
            ),
            rx.hstack(
                rx.hstack(
                    rx.input(
                        variant="soft",
                        background="transparent",
                        outline="none",
                        placeholder="Enter your email",
                        width="100%",
                    ),
                    align="center",
                    spacing="0",
                    border=f"1px solid {rx.color('gray', 6)}",
                    border_radius="8px",
                    padding="5px 5px 5px 10px",
                    flex=["100%" if i <= 3 else "80%" for i in range(6)],
                ),
                rx.button(
                    "Subscribe",
                    variant="solid",
                    flex=["100%" if i <= 3 else "15%" for i in range(6)],
                    size="3",
                ),
                align="center",
                width="100%",
                justify="start",
                flex_wrap="wrap",
            ),
            max_width="30em",
            width="100%",
            align="center",
            spacing="5",
        ),
        width="100%",
        height="25vh",
    )



from dataclasses import dataclass, field

import reflex as rx


@dataclass
class BaseWrapperStyle:
    parent: dict[str, str] = field(
        default_factory=lambda: {
            "spacing": "0",
            "width": "100%",
            "scrollbar_width": "thin",
            "background": rx.color("gray", 2),
            "height": ["100%" if i == 0 else "100vh" for i in range(6)],
        }
    )

    content: dict[str, str] = field(
        default_factory=lambda: {
            "z_index": "5",
            "width": "100%",
            "spacing": "9",
            "padding": "54px 0px 0px 0px",
            "position": "relative",
            "transition": "all 350ms ease",
        }
    )

    header: dict[str, str] = field(
        default_factory=lambda: {
            "top": "0",
            "left": "0",
            "spacing": "2",
            "width": "100%",
            "align": "center",
            "min_height": "25vh",
            "justify": "center",
        }
    )

    background: dict[str, str] = field(
        default_factory=lambda: {
            "background_size": "28px 28px",
            "background_image": f"radial-gradient(circle, {rx.color('slate', 12)} 0.75px, transparent 1px)",
            "mask": (
                "radial-gradient(45% 45% at 50% 50%, hsl(0, 0%, 0%, 0.60), hsl(0, 0%, 0%, 0)), "
                "radial-gradient(60% 70% at 50% 50%, hsl(0, 0%, 0%, 0.35), hsl(0, 0%, 0%, 0))"
            ),
            "width": "100%",
            "height": "50vh",
            "position": "absolute",
            "top": "0",
            "left": "0",
            "z_index": "-2",
        }
    )


BaseWrapperStyle: BaseWrapperStyle = BaseWrapperStyle()



import reflex as rx

from .style import DrawerStyle
from .state import DrawerState

from ..sidemenu.sidemenu import create_sidebar_menu_items
from ...states.routing import SiteRoutingState

active = rx.color("slate", 12)


def drawer_menu_header(title: str):
    return rx.text(title, size="1", color=active, weight="bold", padding="0em 1.25em")


def drawer_menu_link(stack: rx.vstack):
    return rx.vstack(stack, **DrawerStyle.drawer_menu_link)


def drawer():
    return rx.drawer.root(
        rx.drawer.overlay(z_index="50"),
        rx.drawer.portal(
            rx.drawer.content(
                rx.vstack(
                    rx.hstack(
                        rx.heading(
                            "buridan/ui",
                            size="4",
                            font_weight="900",
                            cursor="pointer",
                            on_click=rx.redirect("/"),
                        ),
                        rx.image(src="/logo.jpg", **DrawerStyle.logo),
                        **DrawerStyle.title,
                    ),
                    drawer_menu_header("Getting Started"),
                    drawer_menu_link(
                        create_sidebar_menu_items(SiteRoutingState.GettingStartedRoutes)
                    ),
                    drawer_menu_header("Interactive Apps"),
                    drawer_menu_link(
                        create_sidebar_menu_items(SiteRoutingState.InteractiveRoutes)
                    ),
                    drawer_menu_header("Blueprint Templates"),
                    drawer_menu_link(
                        create_sidebar_menu_items(SiteRoutingState.BlueprintRoutes)
                    ),
                    drawer_menu_header("Charts"),
                    drawer_menu_link(
                        create_sidebar_menu_items(SiteRoutingState.ChartRoutes)
                    ),
                    drawer_menu_header("Pantry"),
                    drawer_menu_link(
                        create_sidebar_menu_items(SiteRoutingState.PantryRoutes)
                    ),
                    **DrawerStyle.stack_content,
                ),
                on_interact_outside=DrawerState.toggle_drawer(),
                **DrawerStyle.content,
            ),
            z_index="50",
        ),
        direction="left",
        open=DrawerState.is_open,
    )



import reflex as rx


def text_wrapper(title: str, description: str):
    return rx.vstack(
        rx.hstack(
            rx.text(
                title,
                size="4",
                weight="bold",
                color=rx.color("slate", 12),
            ),
            align="center",
        ),
        rx.text(description, size="3", color=rx.color("slate", 11), weight="medium"),
        spacing="2",
        line_height="2px",
    )


def buridan():
    return rx.box(
        rx.vstack(
            text_wrapper(
                "Who is Buridan?",
                "Buridan refers to Jean Buridan, a 14th-century French philosopher known for his influential ideas in logic and ethics. One of his most famous thought experiments is the 'Buridan's Ass' paradox, which illustrates the challenges of decision-making in the face of equally appealing choices.",
            ),
            text_wrapper(
                "Why Buridan?",
                "I chose the name 'Buridan UI' to evoke the spirit of thoughtful decision-making in design. Just as Buridan's donkey faced a dilemma between two equally appealing bales of hay, developers often grapple with choices in component design and user experience. This site aims to provide a clear path through those choices by offering beautifully crafted, reusable components that simplify the decision-making process.",
            ),
            text_wrapper(
                "Explore and Create",
                "Dive into our collection of components and see how they can elevate your projects. Whether you’re building a new app or enhancing an existing one, Buridan UI is here to help you navigate the vast landscape of design choices with ease.",
            ),
            max_width="50em",
            width="100%",
            spacing="6",
        ),
        width="100%",
        display="flex",
        justify_content="center",
        padding="0px 14px",
    )
